# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['StorageCapacityUnitArgs', 'StorageCapacityUnit']

@pulumi.input_type
class StorageCapacityUnitArgs:
    def __init__(__self__, *,
                 capacity: pulumi.Input[int],
                 description: Optional[pulumi.Input[str]] = None,
                 period: Optional[pulumi.Input[int]] = None,
                 period_unit: Optional[pulumi.Input[str]] = None,
                 start_time: Optional[pulumi.Input[str]] = None,
                 storage_capacity_unit_name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a StorageCapacityUnit resource.
        :param pulumi.Input[int] capacity: The capacity of the Storage Capacity Unit. Unit: GiB. Valid values: `20`, `40`, `100`, `200`, `500`, `1024`, `2048`, `5120`, `10240`, `20480`, and `51200`.
        :param pulumi.Input[str] description: The description of the Storage Capacity Unit. The description must be 2 to 256 characters in length and cannot start with `http://` or `https://`.
        :param pulumi.Input[int] period: The validity period of the Storage Capacity Unit. Default value: `1`.
               * When PeriodUnit is set to Month, Valid values: `1`, `2`, `3`, `6`.
               * When PeriodUnit is set to Year, Valid values: `1`, `3`, `5`.
        :param pulumi.Input[str] period_unit: The unit of the validity period of the Storage Capacity Unit. Default value: `Month`. Valid values: `Month`, `Year`.
        :param pulumi.Input[str] start_time: The time when the Storage Capacity Unit takes effect. It cannot be earlier than or more than six months later than the time when the Storage Capacity Unit is created. Specify the time in the ISO 8601 standard in the `yyyy-MM-ddTHH:mm:ssZ` format. The time must be in UTC. **NOTE:** This parameter is empty by default. The Storage Capacity Unit immediately takes effect after it is created.
        :param pulumi.Input[str] storage_capacity_unit_name: The name of the Storage Capacity Unit.
        """
        pulumi.set(__self__, "capacity", capacity)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if period is not None:
            pulumi.set(__self__, "period", period)
        if period_unit is not None:
            pulumi.set(__self__, "period_unit", period_unit)
        if start_time is not None:
            pulumi.set(__self__, "start_time", start_time)
        if storage_capacity_unit_name is not None:
            pulumi.set(__self__, "storage_capacity_unit_name", storage_capacity_unit_name)

    @property
    @pulumi.getter
    def capacity(self) -> pulumi.Input[int]:
        """
        The capacity of the Storage Capacity Unit. Unit: GiB. Valid values: `20`, `40`, `100`, `200`, `500`, `1024`, `2048`, `5120`, `10240`, `20480`, and `51200`.
        """
        return pulumi.get(self, "capacity")

    @capacity.setter
    def capacity(self, value: pulumi.Input[int]):
        pulumi.set(self, "capacity", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the Storage Capacity Unit. The description must be 2 to 256 characters in length and cannot start with `http://` or `https://`.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def period(self) -> Optional[pulumi.Input[int]]:
        """
        The validity period of the Storage Capacity Unit. Default value: `1`.
        * When PeriodUnit is set to Month, Valid values: `1`, `2`, `3`, `6`.
        * When PeriodUnit is set to Year, Valid values: `1`, `3`, `5`.
        """
        return pulumi.get(self, "period")

    @period.setter
    def period(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "period", value)

    @property
    @pulumi.getter(name="periodUnit")
    def period_unit(self) -> Optional[pulumi.Input[str]]:
        """
        The unit of the validity period of the Storage Capacity Unit. Default value: `Month`. Valid values: `Month`, `Year`.
        """
        return pulumi.get(self, "period_unit")

    @period_unit.setter
    def period_unit(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "period_unit", value)

    @property
    @pulumi.getter(name="startTime")
    def start_time(self) -> Optional[pulumi.Input[str]]:
        """
        The time when the Storage Capacity Unit takes effect. It cannot be earlier than or more than six months later than the time when the Storage Capacity Unit is created. Specify the time in the ISO 8601 standard in the `yyyy-MM-ddTHH:mm:ssZ` format. The time must be in UTC. **NOTE:** This parameter is empty by default. The Storage Capacity Unit immediately takes effect after it is created.
        """
        return pulumi.get(self, "start_time")

    @start_time.setter
    def start_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "start_time", value)

    @property
    @pulumi.getter(name="storageCapacityUnitName")
    def storage_capacity_unit_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the Storage Capacity Unit.
        """
        return pulumi.get(self, "storage_capacity_unit_name")

    @storage_capacity_unit_name.setter
    def storage_capacity_unit_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "storage_capacity_unit_name", value)


@pulumi.input_type
class _StorageCapacityUnitState:
    def __init__(__self__, *,
                 capacity: Optional[pulumi.Input[int]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 period: Optional[pulumi.Input[int]] = None,
                 period_unit: Optional[pulumi.Input[str]] = None,
                 start_time: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 storage_capacity_unit_name: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering StorageCapacityUnit resources.
        :param pulumi.Input[int] capacity: The capacity of the Storage Capacity Unit. Unit: GiB. Valid values: `20`, `40`, `100`, `200`, `500`, `1024`, `2048`, `5120`, `10240`, `20480`, and `51200`.
        :param pulumi.Input[str] description: The description of the Storage Capacity Unit. The description must be 2 to 256 characters in length and cannot start with `http://` or `https://`.
        :param pulumi.Input[int] period: The validity period of the Storage Capacity Unit. Default value: `1`.
               * When PeriodUnit is set to Month, Valid values: `1`, `2`, `3`, `6`.
               * When PeriodUnit is set to Year, Valid values: `1`, `3`, `5`.
        :param pulumi.Input[str] period_unit: The unit of the validity period of the Storage Capacity Unit. Default value: `Month`. Valid values: `Month`, `Year`.
        :param pulumi.Input[str] start_time: The time when the Storage Capacity Unit takes effect. It cannot be earlier than or more than six months later than the time when the Storage Capacity Unit is created. Specify the time in the ISO 8601 standard in the `yyyy-MM-ddTHH:mm:ssZ` format. The time must be in UTC. **NOTE:** This parameter is empty by default. The Storage Capacity Unit immediately takes effect after it is created.
        :param pulumi.Input[str] status: The status of Storage Capacity Unit.
        :param pulumi.Input[str] storage_capacity_unit_name: The name of the Storage Capacity Unit.
        """
        if capacity is not None:
            pulumi.set(__self__, "capacity", capacity)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if period is not None:
            pulumi.set(__self__, "period", period)
        if period_unit is not None:
            pulumi.set(__self__, "period_unit", period_unit)
        if start_time is not None:
            pulumi.set(__self__, "start_time", start_time)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if storage_capacity_unit_name is not None:
            pulumi.set(__self__, "storage_capacity_unit_name", storage_capacity_unit_name)

    @property
    @pulumi.getter
    def capacity(self) -> Optional[pulumi.Input[int]]:
        """
        The capacity of the Storage Capacity Unit. Unit: GiB. Valid values: `20`, `40`, `100`, `200`, `500`, `1024`, `2048`, `5120`, `10240`, `20480`, and `51200`.
        """
        return pulumi.get(self, "capacity")

    @capacity.setter
    def capacity(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "capacity", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the Storage Capacity Unit. The description must be 2 to 256 characters in length and cannot start with `http://` or `https://`.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def period(self) -> Optional[pulumi.Input[int]]:
        """
        The validity period of the Storage Capacity Unit. Default value: `1`.
        * When PeriodUnit is set to Month, Valid values: `1`, `2`, `3`, `6`.
        * When PeriodUnit is set to Year, Valid values: `1`, `3`, `5`.
        """
        return pulumi.get(self, "period")

    @period.setter
    def period(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "period", value)

    @property
    @pulumi.getter(name="periodUnit")
    def period_unit(self) -> Optional[pulumi.Input[str]]:
        """
        The unit of the validity period of the Storage Capacity Unit. Default value: `Month`. Valid values: `Month`, `Year`.
        """
        return pulumi.get(self, "period_unit")

    @period_unit.setter
    def period_unit(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "period_unit", value)

    @property
    @pulumi.getter(name="startTime")
    def start_time(self) -> Optional[pulumi.Input[str]]:
        """
        The time when the Storage Capacity Unit takes effect. It cannot be earlier than or more than six months later than the time when the Storage Capacity Unit is created. Specify the time in the ISO 8601 standard in the `yyyy-MM-ddTHH:mm:ssZ` format. The time must be in UTC. **NOTE:** This parameter is empty by default. The Storage Capacity Unit immediately takes effect after it is created.
        """
        return pulumi.get(self, "start_time")

    @start_time.setter
    def start_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "start_time", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The status of Storage Capacity Unit.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="storageCapacityUnitName")
    def storage_capacity_unit_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the Storage Capacity Unit.
        """
        return pulumi.get(self, "storage_capacity_unit_name")

    @storage_capacity_unit_name.setter
    def storage_capacity_unit_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "storage_capacity_unit_name", value)


class StorageCapacityUnit(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 capacity: Optional[pulumi.Input[int]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 period: Optional[pulumi.Input[int]] = None,
                 period_unit: Optional[pulumi.Input[str]] = None,
                 start_time: Optional[pulumi.Input[str]] = None,
                 storage_capacity_unit_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a ECS Storage Capacity Unit resource.

        For information about ECS Storage Capacity Unit and how to use it, see [What is Storage Capacity Unit](https://www.alibabacloud.com/help/en/doc-detail/161157.html).

        > **NOTE:** Available in v1.155.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default = alicloud.ecs.StorageCapacityUnit("default",
            capacity=20,
            description="tftestdescription",
            storage_capacity_unit_name="tftestname")
        ```

        ## Import

        ECS Storage Capacity Unit can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:ecs/storageCapacityUnit:StorageCapacityUnit example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[int] capacity: The capacity of the Storage Capacity Unit. Unit: GiB. Valid values: `20`, `40`, `100`, `200`, `500`, `1024`, `2048`, `5120`, `10240`, `20480`, and `51200`.
        :param pulumi.Input[str] description: The description of the Storage Capacity Unit. The description must be 2 to 256 characters in length and cannot start with `http://` or `https://`.
        :param pulumi.Input[int] period: The validity period of the Storage Capacity Unit. Default value: `1`.
               * When PeriodUnit is set to Month, Valid values: `1`, `2`, `3`, `6`.
               * When PeriodUnit is set to Year, Valid values: `1`, `3`, `5`.
        :param pulumi.Input[str] period_unit: The unit of the validity period of the Storage Capacity Unit. Default value: `Month`. Valid values: `Month`, `Year`.
        :param pulumi.Input[str] start_time: The time when the Storage Capacity Unit takes effect. It cannot be earlier than or more than six months later than the time when the Storage Capacity Unit is created. Specify the time in the ISO 8601 standard in the `yyyy-MM-ddTHH:mm:ssZ` format. The time must be in UTC. **NOTE:** This parameter is empty by default. The Storage Capacity Unit immediately takes effect after it is created.
        :param pulumi.Input[str] storage_capacity_unit_name: The name of the Storage Capacity Unit.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: StorageCapacityUnitArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a ECS Storage Capacity Unit resource.

        For information about ECS Storage Capacity Unit and how to use it, see [What is Storage Capacity Unit](https://www.alibabacloud.com/help/en/doc-detail/161157.html).

        > **NOTE:** Available in v1.155.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default = alicloud.ecs.StorageCapacityUnit("default",
            capacity=20,
            description="tftestdescription",
            storage_capacity_unit_name="tftestname")
        ```

        ## Import

        ECS Storage Capacity Unit can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:ecs/storageCapacityUnit:StorageCapacityUnit example <id>
        ```

        :param str resource_name: The name of the resource.
        :param StorageCapacityUnitArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(StorageCapacityUnitArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 capacity: Optional[pulumi.Input[int]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 period: Optional[pulumi.Input[int]] = None,
                 period_unit: Optional[pulumi.Input[str]] = None,
                 start_time: Optional[pulumi.Input[str]] = None,
                 storage_capacity_unit_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = StorageCapacityUnitArgs.__new__(StorageCapacityUnitArgs)

            if capacity is None and not opts.urn:
                raise TypeError("Missing required property 'capacity'")
            __props__.__dict__["capacity"] = capacity
            __props__.__dict__["description"] = description
            __props__.__dict__["period"] = period
            __props__.__dict__["period_unit"] = period_unit
            __props__.__dict__["start_time"] = start_time
            __props__.__dict__["storage_capacity_unit_name"] = storage_capacity_unit_name
            __props__.__dict__["status"] = None
        super(StorageCapacityUnit, __self__).__init__(
            'alicloud:ecs/storageCapacityUnit:StorageCapacityUnit',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            capacity: Optional[pulumi.Input[int]] = None,
            description: Optional[pulumi.Input[str]] = None,
            period: Optional[pulumi.Input[int]] = None,
            period_unit: Optional[pulumi.Input[str]] = None,
            start_time: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None,
            storage_capacity_unit_name: Optional[pulumi.Input[str]] = None) -> 'StorageCapacityUnit':
        """
        Get an existing StorageCapacityUnit resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[int] capacity: The capacity of the Storage Capacity Unit. Unit: GiB. Valid values: `20`, `40`, `100`, `200`, `500`, `1024`, `2048`, `5120`, `10240`, `20480`, and `51200`.
        :param pulumi.Input[str] description: The description of the Storage Capacity Unit. The description must be 2 to 256 characters in length and cannot start with `http://` or `https://`.
        :param pulumi.Input[int] period: The validity period of the Storage Capacity Unit. Default value: `1`.
               * When PeriodUnit is set to Month, Valid values: `1`, `2`, `3`, `6`.
               * When PeriodUnit is set to Year, Valid values: `1`, `3`, `5`.
        :param pulumi.Input[str] period_unit: The unit of the validity period of the Storage Capacity Unit. Default value: `Month`. Valid values: `Month`, `Year`.
        :param pulumi.Input[str] start_time: The time when the Storage Capacity Unit takes effect. It cannot be earlier than or more than six months later than the time when the Storage Capacity Unit is created. Specify the time in the ISO 8601 standard in the `yyyy-MM-ddTHH:mm:ssZ` format. The time must be in UTC. **NOTE:** This parameter is empty by default. The Storage Capacity Unit immediately takes effect after it is created.
        :param pulumi.Input[str] status: The status of Storage Capacity Unit.
        :param pulumi.Input[str] storage_capacity_unit_name: The name of the Storage Capacity Unit.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _StorageCapacityUnitState.__new__(_StorageCapacityUnitState)

        __props__.__dict__["capacity"] = capacity
        __props__.__dict__["description"] = description
        __props__.__dict__["period"] = period
        __props__.__dict__["period_unit"] = period_unit
        __props__.__dict__["start_time"] = start_time
        __props__.__dict__["status"] = status
        __props__.__dict__["storage_capacity_unit_name"] = storage_capacity_unit_name
        return StorageCapacityUnit(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def capacity(self) -> pulumi.Output[int]:
        """
        The capacity of the Storage Capacity Unit. Unit: GiB. Valid values: `20`, `40`, `100`, `200`, `500`, `1024`, `2048`, `5120`, `10240`, `20480`, and `51200`.
        """
        return pulumi.get(self, "capacity")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        The description of the Storage Capacity Unit. The description must be 2 to 256 characters in length and cannot start with `http://` or `https://`.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def period(self) -> pulumi.Output[int]:
        """
        The validity period of the Storage Capacity Unit. Default value: `1`.
        * When PeriodUnit is set to Month, Valid values: `1`, `2`, `3`, `6`.
        * When PeriodUnit is set to Year, Valid values: `1`, `3`, `5`.
        """
        return pulumi.get(self, "period")

    @property
    @pulumi.getter(name="periodUnit")
    def period_unit(self) -> pulumi.Output[str]:
        """
        The unit of the validity period of the Storage Capacity Unit. Default value: `Month`. Valid values: `Month`, `Year`.
        """
        return pulumi.get(self, "period_unit")

    @property
    @pulumi.getter(name="startTime")
    def start_time(self) -> pulumi.Output[str]:
        """
        The time when the Storage Capacity Unit takes effect. It cannot be earlier than or more than six months later than the time when the Storage Capacity Unit is created. Specify the time in the ISO 8601 standard in the `yyyy-MM-ddTHH:mm:ssZ` format. The time must be in UTC. **NOTE:** This parameter is empty by default. The Storage Capacity Unit immediately takes effect after it is created.
        """
        return pulumi.get(self, "start_time")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        The status of Storage Capacity Unit.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="storageCapacityUnitName")
    def storage_capacity_unit_name(self) -> pulumi.Output[str]:
        """
        The name of the Storage Capacity Unit.
        """
        return pulumi.get(self, "storage_capacity_unit_name")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetMainVersionsResult',
    'AwaitableGetMainVersionsResult',
    'get_main_versions',
    'get_main_versions_output',
]

@pulumi.output_type
class GetMainVersionsResult:
    """
    A collection of values returned by getMainVersions.
    """
    def __init__(__self__, cluster_types=None, emr_version=None, id=None, ids=None, main_versions=None, output_file=None):
        if cluster_types and not isinstance(cluster_types, list):
            raise TypeError("Expected argument 'cluster_types' to be a list")
        pulumi.set(__self__, "cluster_types", cluster_types)
        if emr_version and not isinstance(emr_version, str):
            raise TypeError("Expected argument 'emr_version' to be a str")
        pulumi.set(__self__, "emr_version", emr_version)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if main_versions and not isinstance(main_versions, list):
            raise TypeError("Expected argument 'main_versions' to be a list")
        pulumi.set(__self__, "main_versions", main_versions)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)

    @property
    @pulumi.getter(name="clusterTypes")
    def cluster_types(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "cluster_types")

    @property
    @pulumi.getter(name="emrVersion")
    def emr_version(self) -> Optional[str]:
        """
        The version of the emr cluster instance.
        """
        return pulumi.get(self, "emr_version")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        """
        A list of emr instance types IDs.
        """
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="mainVersions")
    def main_versions(self) -> Sequence['outputs.GetMainVersionsMainVersionResult']:
        """
        A list of versions of the emr cluster instance. Each element contains the following attributes:
        """
        return pulumi.get(self, "main_versions")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")


class AwaitableGetMainVersionsResult(GetMainVersionsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetMainVersionsResult(
            cluster_types=self.cluster_types,
            emr_version=self.emr_version,
            id=self.id,
            ids=self.ids,
            main_versions=self.main_versions,
            output_file=self.output_file)


def get_main_versions(cluster_types: Optional[Sequence[str]] = None,
                      emr_version: Optional[str] = None,
                      output_file: Optional[str] = None,
                      opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetMainVersionsResult:
    """
    The `emr_get_main_versions` data source provides a collection of emr
    main versions available in Alibaba Cloud account when create a emr cluster.

    > **NOTE:** Available in 1.59.0+

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    default = alicloud.emr.get_main_versions(cluster_types=[
            "HADOOP",
            "ZOOKEEPER",
        ],
        emr_version="EMR-3.22.0")
    pulumi.export("firstMainVersion", default.main_versions[0].emr_version)
    pulumi.export("thisClusterTypes", default.main_versions[0].cluster_types)
    ```


    :param Sequence[str] cluster_types: The supported clusterType of this emr version.
           Possible values may be any one or combination of these: ["HADOOP", "DRUID", "KAFKA", "ZOOKEEPER", "FLINK", "CLICKHOUSE"]
    :param str emr_version: The version of the emr cluster instance. Possible values: `EMR-4.0.0`, `EMR-3.23.0`, `EMR-3.22.0`.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    """
    __args__ = dict()
    __args__['clusterTypes'] = cluster_types
    __args__['emrVersion'] = emr_version
    __args__['outputFile'] = output_file
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:emr/getMainVersions:getMainVersions', __args__, opts=opts, typ=GetMainVersionsResult).value

    return AwaitableGetMainVersionsResult(
        cluster_types=pulumi.get(__ret__, 'cluster_types'),
        emr_version=pulumi.get(__ret__, 'emr_version'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        main_versions=pulumi.get(__ret__, 'main_versions'),
        output_file=pulumi.get(__ret__, 'output_file'))


@_utilities.lift_output_func(get_main_versions)
def get_main_versions_output(cluster_types: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                             emr_version: Optional[pulumi.Input[Optional[str]]] = None,
                             output_file: Optional[pulumi.Input[Optional[str]]] = None,
                             opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetMainVersionsResult]:
    """
    The `emr_get_main_versions` data source provides a collection of emr
    main versions available in Alibaba Cloud account when create a emr cluster.

    > **NOTE:** Available in 1.59.0+

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    default = alicloud.emr.get_main_versions(cluster_types=[
            "HADOOP",
            "ZOOKEEPER",
        ],
        emr_version="EMR-3.22.0")
    pulumi.export("firstMainVersion", default.main_versions[0].emr_version)
    pulumi.export("thisClusterTypes", default.main_versions[0].cluster_types)
    ```


    :param Sequence[str] cluster_types: The supported clusterType of this emr version.
           Possible values may be any one or combination of these: ["HADOOP", "DRUID", "KAFKA", "ZOOKEEPER", "FLINK", "CLICKHOUSE"]
    :param str emr_version: The version of the emr cluster instance. Possible values: `EMR-4.0.0`, `EMR-3.23.0`, `EMR-3.22.0`.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetOtsBackupPlansResult',
    'AwaitableGetOtsBackupPlansResult',
    'get_ots_backup_plans',
    'get_ots_backup_plans_output',
]

@pulumi.output_type
class GetOtsBackupPlansResult:
    """
    A collection of values returned by getOtsBackupPlans.
    """
    def __init__(__self__, id=None, ids=None, name_regex=None, names=None, output_file=None, plan_id=None, plan_name=None, plans=None, vault_id=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if name_regex and not isinstance(name_regex, str):
            raise TypeError("Expected argument 'name_regex' to be a str")
        pulumi.set(__self__, "name_regex", name_regex)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if plan_id and not isinstance(plan_id, str):
            raise TypeError("Expected argument 'plan_id' to be a str")
        pulumi.set(__self__, "plan_id", plan_id)
        if plan_name and not isinstance(plan_name, str):
            raise TypeError("Expected argument 'plan_name' to be a str")
        pulumi.set(__self__, "plan_name", plan_name)
        if plans and not isinstance(plans, list):
            raise TypeError("Expected argument 'plans' to be a list")
        pulumi.set(__self__, "plans", plans)
        if vault_id and not isinstance(vault_id, str):
            raise TypeError("Expected argument 'vault_id' to be a str")
        pulumi.set(__self__, "vault_id", vault_id)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="nameRegex")
    def name_regex(self) -> Optional[str]:
        return pulumi.get(self, "name_regex")

    @property
    @pulumi.getter
    def names(self) -> Sequence[str]:
        return pulumi.get(self, "names")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter(name="planId")
    def plan_id(self) -> Optional[str]:
        return pulumi.get(self, "plan_id")

    @property
    @pulumi.getter(name="planName")
    def plan_name(self) -> Optional[str]:
        return pulumi.get(self, "plan_name")

    @property
    @pulumi.getter
    def plans(self) -> Sequence['outputs.GetOtsBackupPlansPlanResult']:
        return pulumi.get(self, "plans")

    @property
    @pulumi.getter(name="vaultId")
    def vault_id(self) -> Optional[str]:
        return pulumi.get(self, "vault_id")


class AwaitableGetOtsBackupPlansResult(GetOtsBackupPlansResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetOtsBackupPlansResult(
            id=self.id,
            ids=self.ids,
            name_regex=self.name_regex,
            names=self.names,
            output_file=self.output_file,
            plan_id=self.plan_id,
            plan_name=self.plan_name,
            plans=self.plans,
            vault_id=self.vault_id)


def get_ots_backup_plans(ids: Optional[Sequence[str]] = None,
                         name_regex: Optional[str] = None,
                         output_file: Optional[str] = None,
                         plan_id: Optional[str] = None,
                         plan_name: Optional[str] = None,
                         vault_id: Optional[str] = None,
                         opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetOtsBackupPlansResult:
    """
    This data source provides the Hbr OtsBackupPlans of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.163.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.hbr.get_ots_backup_plans(name_regex="^my-otsBackupPlan")
    pulumi.export("hbrOtsBackupPlanId", data["alicloud_hbr_ots_backup_plans"]["plans"][0]["id"])
    ```


    :param Sequence[str] ids: A list of OtsBackupPlan IDs.
    :param str name_regex: A regex string to filter results by OtsBackupPlan name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str plan_id: The ID of the backup plan.
    :param str plan_name: The ID of the backup plan.
    :param str vault_id: The ID of backup vault.
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['planId'] = plan_id
    __args__['planName'] = plan_name
    __args__['vaultId'] = vault_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:hbr/getOtsBackupPlans:getOtsBackupPlans', __args__, opts=opts, typ=GetOtsBackupPlansResult).value

    return AwaitableGetOtsBackupPlansResult(
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        name_regex=pulumi.get(__ret__, 'name_regex'),
        names=pulumi.get(__ret__, 'names'),
        output_file=pulumi.get(__ret__, 'output_file'),
        plan_id=pulumi.get(__ret__, 'plan_id'),
        plan_name=pulumi.get(__ret__, 'plan_name'),
        plans=pulumi.get(__ret__, 'plans'),
        vault_id=pulumi.get(__ret__, 'vault_id'))


@_utilities.lift_output_func(get_ots_backup_plans)
def get_ots_backup_plans_output(ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                                name_regex: Optional[pulumi.Input[Optional[str]]] = None,
                                output_file: Optional[pulumi.Input[Optional[str]]] = None,
                                plan_id: Optional[pulumi.Input[Optional[str]]] = None,
                                plan_name: Optional[pulumi.Input[Optional[str]]] = None,
                                vault_id: Optional[pulumi.Input[Optional[str]]] = None,
                                opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetOtsBackupPlansResult]:
    """
    This data source provides the Hbr OtsBackupPlans of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.163.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.hbr.get_ots_backup_plans(name_regex="^my-otsBackupPlan")
    pulumi.export("hbrOtsBackupPlanId", data["alicloud_hbr_ots_backup_plans"]["plans"][0]["id"])
    ```


    :param Sequence[str] ids: A list of OtsBackupPlan IDs.
    :param str name_regex: A regex string to filter results by OtsBackupPlan name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str plan_id: The ID of the backup plan.
    :param str plan_name: The ID of the backup plan.
    :param str vault_id: The ID of backup vault.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['AlertArgs', 'Alert']

@pulumi.input_type
class AlertArgs:
    def __init__(__self__, *,
                 alert_displayname: pulumi.Input[str],
                 alert_name: pulumi.Input[str],
                 project_name: pulumi.Input[str],
                 alert_description: Optional[pulumi.Input[str]] = None,
                 annotations: Optional[pulumi.Input[Sequence[pulumi.Input['AlertAnnotationArgs']]]] = None,
                 auto_annotation: Optional[pulumi.Input[bool]] = None,
                 condition: Optional[pulumi.Input[str]] = None,
                 dashboard: Optional[pulumi.Input[str]] = None,
                 group_configuration: Optional[pulumi.Input['AlertGroupConfigurationArgs']] = None,
                 join_configurations: Optional[pulumi.Input[Sequence[pulumi.Input['AlertJoinConfigurationArgs']]]] = None,
                 labels: Optional[pulumi.Input[Sequence[pulumi.Input['AlertLabelArgs']]]] = None,
                 mute_until: Optional[pulumi.Input[int]] = None,
                 no_data_fire: Optional[pulumi.Input[bool]] = None,
                 no_data_severity: Optional[pulumi.Input[int]] = None,
                 notification_lists: Optional[pulumi.Input[Sequence[pulumi.Input['AlertNotificationListArgs']]]] = None,
                 notify_threshold: Optional[pulumi.Input[int]] = None,
                 policy_configuration: Optional[pulumi.Input['AlertPolicyConfigurationArgs']] = None,
                 query_lists: Optional[pulumi.Input[Sequence[pulumi.Input['AlertQueryListArgs']]]] = None,
                 schedule: Optional[pulumi.Input['AlertScheduleArgs']] = None,
                 schedule_interval: Optional[pulumi.Input[str]] = None,
                 schedule_type: Optional[pulumi.Input[str]] = None,
                 send_resolved: Optional[pulumi.Input[bool]] = None,
                 severity_configurations: Optional[pulumi.Input[Sequence[pulumi.Input['AlertSeverityConfigurationArgs']]]] = None,
                 template_configuration: Optional[pulumi.Input['AlertTemplateConfigurationArgs']] = None,
                 threshold: Optional[pulumi.Input[int]] = None,
                 throttling: Optional[pulumi.Input[str]] = None,
                 type: Optional[pulumi.Input[str]] = None,
                 version: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Alert resource.
        :param pulumi.Input[str] alert_displayname: Alert displayname.
        :param pulumi.Input[str] alert_name: Name of logstore for configuring alarm service.
        :param pulumi.Input[str] project_name: The project name.
        :param pulumi.Input[str] alert_description: Alert description.
        :param pulumi.Input[Sequence[pulumi.Input['AlertAnnotationArgs']]] annotations: Alert template annotations.
        :param pulumi.Input[bool] auto_annotation: whether to add automatic annotation, default is false.
        :param pulumi.Input[str] condition: Join condition.
        :param pulumi.Input['AlertGroupConfigurationArgs'] group_configuration: Group configuration for new alert.
        :param pulumi.Input[Sequence[pulumi.Input['AlertJoinConfigurationArgs']]] join_configurations: Join configuration for different queries.
        :param pulumi.Input[Sequence[pulumi.Input['AlertLabelArgs']]] labels: Labels for new alert.
        :param pulumi.Input[int] mute_until: Timestamp, notifications before closing again.
        :param pulumi.Input[bool] no_data_fire: Switch for whether new alert fires when no data happens, default is false.
        :param pulumi.Input[int] no_data_severity: when no data happens, the severity of new alert.
        :param pulumi.Input[Sequence[pulumi.Input['AlertNotificationListArgs']]] notification_lists: Alarm information notification list, Deprecated from 1.161.0+.
        :param pulumi.Input[int] notify_threshold: Notification threshold, which is not notified until the number of triggers is reached. The default is 1, Deprecated from 1.161.0+.
        :param pulumi.Input['AlertPolicyConfigurationArgs'] policy_configuration: Policy configuration for new alert.
        :param pulumi.Input[Sequence[pulumi.Input['AlertQueryListArgs']]] query_lists: Multiple conditions for configured alarm query.
        :param pulumi.Input['AlertScheduleArgs'] schedule: schedule for alert.
        :param pulumi.Input[str] schedule_interval: Execution interval. 60 seconds minimum, such as 60s, 1h. Deprecated from 1.176.0+. use interval in schedule.
        :param pulumi.Input[str] schedule_type: Default FixedRate. No need to configure this parameter. Deprecated from 1.176.0+. use type in schedule.
        :param pulumi.Input[bool] send_resolved: when new alert is resolved, whether to notify, default is false.
        :param pulumi.Input[Sequence[pulumi.Input['AlertSeverityConfigurationArgs']]] severity_configurations: Severity configuration for new alert.
        :param pulumi.Input['AlertTemplateConfigurationArgs'] template_configuration: Template configuration for alert, when `type` is `tpl`.
        :param pulumi.Input[int] threshold: Evaluation threshold, alert will not fire until the number of triggers is reached. The default is 1.
        :param pulumi.Input[str] throttling: Notification interval, default is no interval. Support number + unit type, for example 60s, 1h, Deprecated from 1.161.0+.
        :param pulumi.Input[str] type: including FixedRate,Hourly,Daily,Weekly,Cron.
        :param pulumi.Input[str] version: The version of alert, new alert is 2.0.
        """
        pulumi.set(__self__, "alert_displayname", alert_displayname)
        pulumi.set(__self__, "alert_name", alert_name)
        pulumi.set(__self__, "project_name", project_name)
        if alert_description is not None:
            pulumi.set(__self__, "alert_description", alert_description)
        if annotations is not None:
            pulumi.set(__self__, "annotations", annotations)
        if auto_annotation is not None:
            pulumi.set(__self__, "auto_annotation", auto_annotation)
        if condition is not None:
            warnings.warn("""Deprecated from 1.161.0+, use eval_condition in severity_configurations""", DeprecationWarning)
            pulumi.log.warn("""condition is deprecated: Deprecated from 1.161.0+, use eval_condition in severity_configurations""")
        if condition is not None:
            pulumi.set(__self__, "condition", condition)
        if dashboard is not None:
            warnings.warn("""Deprecated from 1.161.0+, use dashboardId in query_list""", DeprecationWarning)
            pulumi.log.warn("""dashboard is deprecated: Deprecated from 1.161.0+, use dashboardId in query_list""")
        if dashboard is not None:
            pulumi.set(__self__, "dashboard", dashboard)
        if group_configuration is not None:
            pulumi.set(__self__, "group_configuration", group_configuration)
        if join_configurations is not None:
            pulumi.set(__self__, "join_configurations", join_configurations)
        if labels is not None:
            pulumi.set(__self__, "labels", labels)
        if mute_until is not None:
            pulumi.set(__self__, "mute_until", mute_until)
        if no_data_fire is not None:
            pulumi.set(__self__, "no_data_fire", no_data_fire)
        if no_data_severity is not None:
            pulumi.set(__self__, "no_data_severity", no_data_severity)
        if notification_lists is not None:
            warnings.warn("""Deprecated from 1.161.0+, use policy_configuration for notification""", DeprecationWarning)
            pulumi.log.warn("""notification_lists is deprecated: Deprecated from 1.161.0+, use policy_configuration for notification""")
        if notification_lists is not None:
            pulumi.set(__self__, "notification_lists", notification_lists)
        if notify_threshold is not None:
            warnings.warn("""Deprecated from 1.161.0+, use threshold""", DeprecationWarning)
            pulumi.log.warn("""notify_threshold is deprecated: Deprecated from 1.161.0+, use threshold""")
        if notify_threshold is not None:
            pulumi.set(__self__, "notify_threshold", notify_threshold)
        if policy_configuration is not None:
            pulumi.set(__self__, "policy_configuration", policy_configuration)
        if query_lists is not None:
            pulumi.set(__self__, "query_lists", query_lists)
        if schedule is not None:
            pulumi.set(__self__, "schedule", schedule)
        if schedule_interval is not None:
            warnings.warn("""Field 'schedule_interval' has been deprecated from provider version 1.176.0. New field 'schedule' instead.""", DeprecationWarning)
            pulumi.log.warn("""schedule_interval is deprecated: Field 'schedule_interval' has been deprecated from provider version 1.176.0. New field 'schedule' instead.""")
        if schedule_interval is not None:
            pulumi.set(__self__, "schedule_interval", schedule_interval)
        if schedule_type is not None:
            warnings.warn("""Field 'schedule_type' has been deprecated from provider version 1.176.0. New field 'schedule' instead.""", DeprecationWarning)
            pulumi.log.warn("""schedule_type is deprecated: Field 'schedule_type' has been deprecated from provider version 1.176.0. New field 'schedule' instead.""")
        if schedule_type is not None:
            pulumi.set(__self__, "schedule_type", schedule_type)
        if send_resolved is not None:
            pulumi.set(__self__, "send_resolved", send_resolved)
        if severity_configurations is not None:
            pulumi.set(__self__, "severity_configurations", severity_configurations)
        if template_configuration is not None:
            pulumi.set(__self__, "template_configuration", template_configuration)
        if threshold is not None:
            pulumi.set(__self__, "threshold", threshold)
        if throttling is not None:
            warnings.warn("""Deprecated from 1.161.0+, use repeat_interval in policy_configuration""", DeprecationWarning)
            pulumi.log.warn("""throttling is deprecated: Deprecated from 1.161.0+, use repeat_interval in policy_configuration""")
        if throttling is not None:
            pulumi.set(__self__, "throttling", throttling)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if version is not None:
            pulumi.set(__self__, "version", version)

    @property
    @pulumi.getter(name="alertDisplayname")
    def alert_displayname(self) -> pulumi.Input[str]:
        """
        Alert displayname.
        """
        return pulumi.get(self, "alert_displayname")

    @alert_displayname.setter
    def alert_displayname(self, value: pulumi.Input[str]):
        pulumi.set(self, "alert_displayname", value)

    @property
    @pulumi.getter(name="alertName")
    def alert_name(self) -> pulumi.Input[str]:
        """
        Name of logstore for configuring alarm service.
        """
        return pulumi.get(self, "alert_name")

    @alert_name.setter
    def alert_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "alert_name", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Input[str]:
        """
        The project name.
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="alertDescription")
    def alert_description(self) -> Optional[pulumi.Input[str]]:
        """
        Alert description.
        """
        return pulumi.get(self, "alert_description")

    @alert_description.setter
    def alert_description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "alert_description", value)

    @property
    @pulumi.getter
    def annotations(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AlertAnnotationArgs']]]]:
        """
        Alert template annotations.
        """
        return pulumi.get(self, "annotations")

    @annotations.setter
    def annotations(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AlertAnnotationArgs']]]]):
        pulumi.set(self, "annotations", value)

    @property
    @pulumi.getter(name="autoAnnotation")
    def auto_annotation(self) -> Optional[pulumi.Input[bool]]:
        """
        whether to add automatic annotation, default is false.
        """
        return pulumi.get(self, "auto_annotation")

    @auto_annotation.setter
    def auto_annotation(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "auto_annotation", value)

    @property
    @pulumi.getter
    def condition(self) -> Optional[pulumi.Input[str]]:
        """
        Join condition.
        """
        warnings.warn("""Deprecated from 1.161.0+, use eval_condition in severity_configurations""", DeprecationWarning)
        pulumi.log.warn("""condition is deprecated: Deprecated from 1.161.0+, use eval_condition in severity_configurations""")

        return pulumi.get(self, "condition")

    @condition.setter
    def condition(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "condition", value)

    @property
    @pulumi.getter
    def dashboard(self) -> Optional[pulumi.Input[str]]:
        warnings.warn("""Deprecated from 1.161.0+, use dashboardId in query_list""", DeprecationWarning)
        pulumi.log.warn("""dashboard is deprecated: Deprecated from 1.161.0+, use dashboardId in query_list""")

        return pulumi.get(self, "dashboard")

    @dashboard.setter
    def dashboard(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dashboard", value)

    @property
    @pulumi.getter(name="groupConfiguration")
    def group_configuration(self) -> Optional[pulumi.Input['AlertGroupConfigurationArgs']]:
        """
        Group configuration for new alert.
        """
        return pulumi.get(self, "group_configuration")

    @group_configuration.setter
    def group_configuration(self, value: Optional[pulumi.Input['AlertGroupConfigurationArgs']]):
        pulumi.set(self, "group_configuration", value)

    @property
    @pulumi.getter(name="joinConfigurations")
    def join_configurations(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AlertJoinConfigurationArgs']]]]:
        """
        Join configuration for different queries.
        """
        return pulumi.get(self, "join_configurations")

    @join_configurations.setter
    def join_configurations(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AlertJoinConfigurationArgs']]]]):
        pulumi.set(self, "join_configurations", value)

    @property
    @pulumi.getter
    def labels(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AlertLabelArgs']]]]:
        """
        Labels for new alert.
        """
        return pulumi.get(self, "labels")

    @labels.setter
    def labels(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AlertLabelArgs']]]]):
        pulumi.set(self, "labels", value)

    @property
    @pulumi.getter(name="muteUntil")
    def mute_until(self) -> Optional[pulumi.Input[int]]:
        """
        Timestamp, notifications before closing again.
        """
        return pulumi.get(self, "mute_until")

    @mute_until.setter
    def mute_until(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "mute_until", value)

    @property
    @pulumi.getter(name="noDataFire")
    def no_data_fire(self) -> Optional[pulumi.Input[bool]]:
        """
        Switch for whether new alert fires when no data happens, default is false.
        """
        return pulumi.get(self, "no_data_fire")

    @no_data_fire.setter
    def no_data_fire(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "no_data_fire", value)

    @property
    @pulumi.getter(name="noDataSeverity")
    def no_data_severity(self) -> Optional[pulumi.Input[int]]:
        """
        when no data happens, the severity of new alert.
        """
        return pulumi.get(self, "no_data_severity")

    @no_data_severity.setter
    def no_data_severity(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "no_data_severity", value)

    @property
    @pulumi.getter(name="notificationLists")
    def notification_lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AlertNotificationListArgs']]]]:
        """
        Alarm information notification list, Deprecated from 1.161.0+.
        """
        warnings.warn("""Deprecated from 1.161.0+, use policy_configuration for notification""", DeprecationWarning)
        pulumi.log.warn("""notification_lists is deprecated: Deprecated from 1.161.0+, use policy_configuration for notification""")

        return pulumi.get(self, "notification_lists")

    @notification_lists.setter
    def notification_lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AlertNotificationListArgs']]]]):
        pulumi.set(self, "notification_lists", value)

    @property
    @pulumi.getter(name="notifyThreshold")
    def notify_threshold(self) -> Optional[pulumi.Input[int]]:
        """
        Notification threshold, which is not notified until the number of triggers is reached. The default is 1, Deprecated from 1.161.0+.
        """
        warnings.warn("""Deprecated from 1.161.0+, use threshold""", DeprecationWarning)
        pulumi.log.warn("""notify_threshold is deprecated: Deprecated from 1.161.0+, use threshold""")

        return pulumi.get(self, "notify_threshold")

    @notify_threshold.setter
    def notify_threshold(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "notify_threshold", value)

    @property
    @pulumi.getter(name="policyConfiguration")
    def policy_configuration(self) -> Optional[pulumi.Input['AlertPolicyConfigurationArgs']]:
        """
        Policy configuration for new alert.
        """
        return pulumi.get(self, "policy_configuration")

    @policy_configuration.setter
    def policy_configuration(self, value: Optional[pulumi.Input['AlertPolicyConfigurationArgs']]):
        pulumi.set(self, "policy_configuration", value)

    @property
    @pulumi.getter(name="queryLists")
    def query_lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AlertQueryListArgs']]]]:
        """
        Multiple conditions for configured alarm query.
        """
        return pulumi.get(self, "query_lists")

    @query_lists.setter
    def query_lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AlertQueryListArgs']]]]):
        pulumi.set(self, "query_lists", value)

    @property
    @pulumi.getter
    def schedule(self) -> Optional[pulumi.Input['AlertScheduleArgs']]:
        """
        schedule for alert.
        """
        return pulumi.get(self, "schedule")

    @schedule.setter
    def schedule(self, value: Optional[pulumi.Input['AlertScheduleArgs']]):
        pulumi.set(self, "schedule", value)

    @property
    @pulumi.getter(name="scheduleInterval")
    def schedule_interval(self) -> Optional[pulumi.Input[str]]:
        """
        Execution interval. 60 seconds minimum, such as 60s, 1h. Deprecated from 1.176.0+. use interval in schedule.
        """
        warnings.warn("""Field 'schedule_interval' has been deprecated from provider version 1.176.0. New field 'schedule' instead.""", DeprecationWarning)
        pulumi.log.warn("""schedule_interval is deprecated: Field 'schedule_interval' has been deprecated from provider version 1.176.0. New field 'schedule' instead.""")

        return pulumi.get(self, "schedule_interval")

    @schedule_interval.setter
    def schedule_interval(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "schedule_interval", value)

    @property
    @pulumi.getter(name="scheduleType")
    def schedule_type(self) -> Optional[pulumi.Input[str]]:
        """
        Default FixedRate. No need to configure this parameter. Deprecated from 1.176.0+. use type in schedule.
        """
        warnings.warn("""Field 'schedule_type' has been deprecated from provider version 1.176.0. New field 'schedule' instead.""", DeprecationWarning)
        pulumi.log.warn("""schedule_type is deprecated: Field 'schedule_type' has been deprecated from provider version 1.176.0. New field 'schedule' instead.""")

        return pulumi.get(self, "schedule_type")

    @schedule_type.setter
    def schedule_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "schedule_type", value)

    @property
    @pulumi.getter(name="sendResolved")
    def send_resolved(self) -> Optional[pulumi.Input[bool]]:
        """
        when new alert is resolved, whether to notify, default is false.
        """
        return pulumi.get(self, "send_resolved")

    @send_resolved.setter
    def send_resolved(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "send_resolved", value)

    @property
    @pulumi.getter(name="severityConfigurations")
    def severity_configurations(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AlertSeverityConfigurationArgs']]]]:
        """
        Severity configuration for new alert.
        """
        return pulumi.get(self, "severity_configurations")

    @severity_configurations.setter
    def severity_configurations(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AlertSeverityConfigurationArgs']]]]):
        pulumi.set(self, "severity_configurations", value)

    @property
    @pulumi.getter(name="templateConfiguration")
    def template_configuration(self) -> Optional[pulumi.Input['AlertTemplateConfigurationArgs']]:
        """
        Template configuration for alert, when `type` is `tpl`.
        """
        return pulumi.get(self, "template_configuration")

    @template_configuration.setter
    def template_configuration(self, value: Optional[pulumi.Input['AlertTemplateConfigurationArgs']]):
        pulumi.set(self, "template_configuration", value)

    @property
    @pulumi.getter
    def threshold(self) -> Optional[pulumi.Input[int]]:
        """
        Evaluation threshold, alert will not fire until the number of triggers is reached. The default is 1.
        """
        return pulumi.get(self, "threshold")

    @threshold.setter
    def threshold(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "threshold", value)

    @property
    @pulumi.getter
    def throttling(self) -> Optional[pulumi.Input[str]]:
        """
        Notification interval, default is no interval. Support number + unit type, for example 60s, 1h, Deprecated from 1.161.0+.
        """
        warnings.warn("""Deprecated from 1.161.0+, use repeat_interval in policy_configuration""", DeprecationWarning)
        pulumi.log.warn("""throttling is deprecated: Deprecated from 1.161.0+, use repeat_interval in policy_configuration""")

        return pulumi.get(self, "throttling")

    @throttling.setter
    def throttling(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "throttling", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[str]]:
        """
        including FixedRate,Hourly,Daily,Weekly,Cron.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter
    def version(self) -> Optional[pulumi.Input[str]]:
        """
        The version of alert, new alert is 2.0.
        """
        return pulumi.get(self, "version")

    @version.setter
    def version(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "version", value)


@pulumi.input_type
class _AlertState:
    def __init__(__self__, *,
                 alert_description: Optional[pulumi.Input[str]] = None,
                 alert_displayname: Optional[pulumi.Input[str]] = None,
                 alert_name: Optional[pulumi.Input[str]] = None,
                 annotations: Optional[pulumi.Input[Sequence[pulumi.Input['AlertAnnotationArgs']]]] = None,
                 auto_annotation: Optional[pulumi.Input[bool]] = None,
                 condition: Optional[pulumi.Input[str]] = None,
                 dashboard: Optional[pulumi.Input[str]] = None,
                 group_configuration: Optional[pulumi.Input['AlertGroupConfigurationArgs']] = None,
                 join_configurations: Optional[pulumi.Input[Sequence[pulumi.Input['AlertJoinConfigurationArgs']]]] = None,
                 labels: Optional[pulumi.Input[Sequence[pulumi.Input['AlertLabelArgs']]]] = None,
                 mute_until: Optional[pulumi.Input[int]] = None,
                 no_data_fire: Optional[pulumi.Input[bool]] = None,
                 no_data_severity: Optional[pulumi.Input[int]] = None,
                 notification_lists: Optional[pulumi.Input[Sequence[pulumi.Input['AlertNotificationListArgs']]]] = None,
                 notify_threshold: Optional[pulumi.Input[int]] = None,
                 policy_configuration: Optional[pulumi.Input['AlertPolicyConfigurationArgs']] = None,
                 project_name: Optional[pulumi.Input[str]] = None,
                 query_lists: Optional[pulumi.Input[Sequence[pulumi.Input['AlertQueryListArgs']]]] = None,
                 schedule: Optional[pulumi.Input['AlertScheduleArgs']] = None,
                 schedule_interval: Optional[pulumi.Input[str]] = None,
                 schedule_type: Optional[pulumi.Input[str]] = None,
                 send_resolved: Optional[pulumi.Input[bool]] = None,
                 severity_configurations: Optional[pulumi.Input[Sequence[pulumi.Input['AlertSeverityConfigurationArgs']]]] = None,
                 template_configuration: Optional[pulumi.Input['AlertTemplateConfigurationArgs']] = None,
                 threshold: Optional[pulumi.Input[int]] = None,
                 throttling: Optional[pulumi.Input[str]] = None,
                 type: Optional[pulumi.Input[str]] = None,
                 version: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Alert resources.
        :param pulumi.Input[str] alert_description: Alert description.
        :param pulumi.Input[str] alert_displayname: Alert displayname.
        :param pulumi.Input[str] alert_name: Name of logstore for configuring alarm service.
        :param pulumi.Input[Sequence[pulumi.Input['AlertAnnotationArgs']]] annotations: Alert template annotations.
        :param pulumi.Input[bool] auto_annotation: whether to add automatic annotation, default is false.
        :param pulumi.Input[str] condition: Join condition.
        :param pulumi.Input['AlertGroupConfigurationArgs'] group_configuration: Group configuration for new alert.
        :param pulumi.Input[Sequence[pulumi.Input['AlertJoinConfigurationArgs']]] join_configurations: Join configuration for different queries.
        :param pulumi.Input[Sequence[pulumi.Input['AlertLabelArgs']]] labels: Labels for new alert.
        :param pulumi.Input[int] mute_until: Timestamp, notifications before closing again.
        :param pulumi.Input[bool] no_data_fire: Switch for whether new alert fires when no data happens, default is false.
        :param pulumi.Input[int] no_data_severity: when no data happens, the severity of new alert.
        :param pulumi.Input[Sequence[pulumi.Input['AlertNotificationListArgs']]] notification_lists: Alarm information notification list, Deprecated from 1.161.0+.
        :param pulumi.Input[int] notify_threshold: Notification threshold, which is not notified until the number of triggers is reached. The default is 1, Deprecated from 1.161.0+.
        :param pulumi.Input['AlertPolicyConfigurationArgs'] policy_configuration: Policy configuration for new alert.
        :param pulumi.Input[str] project_name: The project name.
        :param pulumi.Input[Sequence[pulumi.Input['AlertQueryListArgs']]] query_lists: Multiple conditions for configured alarm query.
        :param pulumi.Input['AlertScheduleArgs'] schedule: schedule for alert.
        :param pulumi.Input[str] schedule_interval: Execution interval. 60 seconds minimum, such as 60s, 1h. Deprecated from 1.176.0+. use interval in schedule.
        :param pulumi.Input[str] schedule_type: Default FixedRate. No need to configure this parameter. Deprecated from 1.176.0+. use type in schedule.
        :param pulumi.Input[bool] send_resolved: when new alert is resolved, whether to notify, default is false.
        :param pulumi.Input[Sequence[pulumi.Input['AlertSeverityConfigurationArgs']]] severity_configurations: Severity configuration for new alert.
        :param pulumi.Input['AlertTemplateConfigurationArgs'] template_configuration: Template configuration for alert, when `type` is `tpl`.
        :param pulumi.Input[int] threshold: Evaluation threshold, alert will not fire until the number of triggers is reached. The default is 1.
        :param pulumi.Input[str] throttling: Notification interval, default is no interval. Support number + unit type, for example 60s, 1h, Deprecated from 1.161.0+.
        :param pulumi.Input[str] type: including FixedRate,Hourly,Daily,Weekly,Cron.
        :param pulumi.Input[str] version: The version of alert, new alert is 2.0.
        """
        if alert_description is not None:
            pulumi.set(__self__, "alert_description", alert_description)
        if alert_displayname is not None:
            pulumi.set(__self__, "alert_displayname", alert_displayname)
        if alert_name is not None:
            pulumi.set(__self__, "alert_name", alert_name)
        if annotations is not None:
            pulumi.set(__self__, "annotations", annotations)
        if auto_annotation is not None:
            pulumi.set(__self__, "auto_annotation", auto_annotation)
        if condition is not None:
            warnings.warn("""Deprecated from 1.161.0+, use eval_condition in severity_configurations""", DeprecationWarning)
            pulumi.log.warn("""condition is deprecated: Deprecated from 1.161.0+, use eval_condition in severity_configurations""")
        if condition is not None:
            pulumi.set(__self__, "condition", condition)
        if dashboard is not None:
            warnings.warn("""Deprecated from 1.161.0+, use dashboardId in query_list""", DeprecationWarning)
            pulumi.log.warn("""dashboard is deprecated: Deprecated from 1.161.0+, use dashboardId in query_list""")
        if dashboard is not None:
            pulumi.set(__self__, "dashboard", dashboard)
        if group_configuration is not None:
            pulumi.set(__self__, "group_configuration", group_configuration)
        if join_configurations is not None:
            pulumi.set(__self__, "join_configurations", join_configurations)
        if labels is not None:
            pulumi.set(__self__, "labels", labels)
        if mute_until is not None:
            pulumi.set(__self__, "mute_until", mute_until)
        if no_data_fire is not None:
            pulumi.set(__self__, "no_data_fire", no_data_fire)
        if no_data_severity is not None:
            pulumi.set(__self__, "no_data_severity", no_data_severity)
        if notification_lists is not None:
            warnings.warn("""Deprecated from 1.161.0+, use policy_configuration for notification""", DeprecationWarning)
            pulumi.log.warn("""notification_lists is deprecated: Deprecated from 1.161.0+, use policy_configuration for notification""")
        if notification_lists is not None:
            pulumi.set(__self__, "notification_lists", notification_lists)
        if notify_threshold is not None:
            warnings.warn("""Deprecated from 1.161.0+, use threshold""", DeprecationWarning)
            pulumi.log.warn("""notify_threshold is deprecated: Deprecated from 1.161.0+, use threshold""")
        if notify_threshold is not None:
            pulumi.set(__self__, "notify_threshold", notify_threshold)
        if policy_configuration is not None:
            pulumi.set(__self__, "policy_configuration", policy_configuration)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if query_lists is not None:
            pulumi.set(__self__, "query_lists", query_lists)
        if schedule is not None:
            pulumi.set(__self__, "schedule", schedule)
        if schedule_interval is not None:
            warnings.warn("""Field 'schedule_interval' has been deprecated from provider version 1.176.0. New field 'schedule' instead.""", DeprecationWarning)
            pulumi.log.warn("""schedule_interval is deprecated: Field 'schedule_interval' has been deprecated from provider version 1.176.0. New field 'schedule' instead.""")
        if schedule_interval is not None:
            pulumi.set(__self__, "schedule_interval", schedule_interval)
        if schedule_type is not None:
            warnings.warn("""Field 'schedule_type' has been deprecated from provider version 1.176.0. New field 'schedule' instead.""", DeprecationWarning)
            pulumi.log.warn("""schedule_type is deprecated: Field 'schedule_type' has been deprecated from provider version 1.176.0. New field 'schedule' instead.""")
        if schedule_type is not None:
            pulumi.set(__self__, "schedule_type", schedule_type)
        if send_resolved is not None:
            pulumi.set(__self__, "send_resolved", send_resolved)
        if severity_configurations is not None:
            pulumi.set(__self__, "severity_configurations", severity_configurations)
        if template_configuration is not None:
            pulumi.set(__self__, "template_configuration", template_configuration)
        if threshold is not None:
            pulumi.set(__self__, "threshold", threshold)
        if throttling is not None:
            warnings.warn("""Deprecated from 1.161.0+, use repeat_interval in policy_configuration""", DeprecationWarning)
            pulumi.log.warn("""throttling is deprecated: Deprecated from 1.161.0+, use repeat_interval in policy_configuration""")
        if throttling is not None:
            pulumi.set(__self__, "throttling", throttling)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if version is not None:
            pulumi.set(__self__, "version", version)

    @property
    @pulumi.getter(name="alertDescription")
    def alert_description(self) -> Optional[pulumi.Input[str]]:
        """
        Alert description.
        """
        return pulumi.get(self, "alert_description")

    @alert_description.setter
    def alert_description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "alert_description", value)

    @property
    @pulumi.getter(name="alertDisplayname")
    def alert_displayname(self) -> Optional[pulumi.Input[str]]:
        """
        Alert displayname.
        """
        return pulumi.get(self, "alert_displayname")

    @alert_displayname.setter
    def alert_displayname(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "alert_displayname", value)

    @property
    @pulumi.getter(name="alertName")
    def alert_name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of logstore for configuring alarm service.
        """
        return pulumi.get(self, "alert_name")

    @alert_name.setter
    def alert_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "alert_name", value)

    @property
    @pulumi.getter
    def annotations(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AlertAnnotationArgs']]]]:
        """
        Alert template annotations.
        """
        return pulumi.get(self, "annotations")

    @annotations.setter
    def annotations(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AlertAnnotationArgs']]]]):
        pulumi.set(self, "annotations", value)

    @property
    @pulumi.getter(name="autoAnnotation")
    def auto_annotation(self) -> Optional[pulumi.Input[bool]]:
        """
        whether to add automatic annotation, default is false.
        """
        return pulumi.get(self, "auto_annotation")

    @auto_annotation.setter
    def auto_annotation(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "auto_annotation", value)

    @property
    @pulumi.getter
    def condition(self) -> Optional[pulumi.Input[str]]:
        """
        Join condition.
        """
        warnings.warn("""Deprecated from 1.161.0+, use eval_condition in severity_configurations""", DeprecationWarning)
        pulumi.log.warn("""condition is deprecated: Deprecated from 1.161.0+, use eval_condition in severity_configurations""")

        return pulumi.get(self, "condition")

    @condition.setter
    def condition(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "condition", value)

    @property
    @pulumi.getter
    def dashboard(self) -> Optional[pulumi.Input[str]]:
        warnings.warn("""Deprecated from 1.161.0+, use dashboardId in query_list""", DeprecationWarning)
        pulumi.log.warn("""dashboard is deprecated: Deprecated from 1.161.0+, use dashboardId in query_list""")

        return pulumi.get(self, "dashboard")

    @dashboard.setter
    def dashboard(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dashboard", value)

    @property
    @pulumi.getter(name="groupConfiguration")
    def group_configuration(self) -> Optional[pulumi.Input['AlertGroupConfigurationArgs']]:
        """
        Group configuration for new alert.
        """
        return pulumi.get(self, "group_configuration")

    @group_configuration.setter
    def group_configuration(self, value: Optional[pulumi.Input['AlertGroupConfigurationArgs']]):
        pulumi.set(self, "group_configuration", value)

    @property
    @pulumi.getter(name="joinConfigurations")
    def join_configurations(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AlertJoinConfigurationArgs']]]]:
        """
        Join configuration for different queries.
        """
        return pulumi.get(self, "join_configurations")

    @join_configurations.setter
    def join_configurations(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AlertJoinConfigurationArgs']]]]):
        pulumi.set(self, "join_configurations", value)

    @property
    @pulumi.getter
    def labels(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AlertLabelArgs']]]]:
        """
        Labels for new alert.
        """
        return pulumi.get(self, "labels")

    @labels.setter
    def labels(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AlertLabelArgs']]]]):
        pulumi.set(self, "labels", value)

    @property
    @pulumi.getter(name="muteUntil")
    def mute_until(self) -> Optional[pulumi.Input[int]]:
        """
        Timestamp, notifications before closing again.
        """
        return pulumi.get(self, "mute_until")

    @mute_until.setter
    def mute_until(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "mute_until", value)

    @property
    @pulumi.getter(name="noDataFire")
    def no_data_fire(self) -> Optional[pulumi.Input[bool]]:
        """
        Switch for whether new alert fires when no data happens, default is false.
        """
        return pulumi.get(self, "no_data_fire")

    @no_data_fire.setter
    def no_data_fire(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "no_data_fire", value)

    @property
    @pulumi.getter(name="noDataSeverity")
    def no_data_severity(self) -> Optional[pulumi.Input[int]]:
        """
        when no data happens, the severity of new alert.
        """
        return pulumi.get(self, "no_data_severity")

    @no_data_severity.setter
    def no_data_severity(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "no_data_severity", value)

    @property
    @pulumi.getter(name="notificationLists")
    def notification_lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AlertNotificationListArgs']]]]:
        """
        Alarm information notification list, Deprecated from 1.161.0+.
        """
        warnings.warn("""Deprecated from 1.161.0+, use policy_configuration for notification""", DeprecationWarning)
        pulumi.log.warn("""notification_lists is deprecated: Deprecated from 1.161.0+, use policy_configuration for notification""")

        return pulumi.get(self, "notification_lists")

    @notification_lists.setter
    def notification_lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AlertNotificationListArgs']]]]):
        pulumi.set(self, "notification_lists", value)

    @property
    @pulumi.getter(name="notifyThreshold")
    def notify_threshold(self) -> Optional[pulumi.Input[int]]:
        """
        Notification threshold, which is not notified until the number of triggers is reached. The default is 1, Deprecated from 1.161.0+.
        """
        warnings.warn("""Deprecated from 1.161.0+, use threshold""", DeprecationWarning)
        pulumi.log.warn("""notify_threshold is deprecated: Deprecated from 1.161.0+, use threshold""")

        return pulumi.get(self, "notify_threshold")

    @notify_threshold.setter
    def notify_threshold(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "notify_threshold", value)

    @property
    @pulumi.getter(name="policyConfiguration")
    def policy_configuration(self) -> Optional[pulumi.Input['AlertPolicyConfigurationArgs']]:
        """
        Policy configuration for new alert.
        """
        return pulumi.get(self, "policy_configuration")

    @policy_configuration.setter
    def policy_configuration(self, value: Optional[pulumi.Input['AlertPolicyConfigurationArgs']]):
        pulumi.set(self, "policy_configuration", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[str]]:
        """
        The project name.
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="queryLists")
    def query_lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AlertQueryListArgs']]]]:
        """
        Multiple conditions for configured alarm query.
        """
        return pulumi.get(self, "query_lists")

    @query_lists.setter
    def query_lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AlertQueryListArgs']]]]):
        pulumi.set(self, "query_lists", value)

    @property
    @pulumi.getter
    def schedule(self) -> Optional[pulumi.Input['AlertScheduleArgs']]:
        """
        schedule for alert.
        """
        return pulumi.get(self, "schedule")

    @schedule.setter
    def schedule(self, value: Optional[pulumi.Input['AlertScheduleArgs']]):
        pulumi.set(self, "schedule", value)

    @property
    @pulumi.getter(name="scheduleInterval")
    def schedule_interval(self) -> Optional[pulumi.Input[str]]:
        """
        Execution interval. 60 seconds minimum, such as 60s, 1h. Deprecated from 1.176.0+. use interval in schedule.
        """
        warnings.warn("""Field 'schedule_interval' has been deprecated from provider version 1.176.0. New field 'schedule' instead.""", DeprecationWarning)
        pulumi.log.warn("""schedule_interval is deprecated: Field 'schedule_interval' has been deprecated from provider version 1.176.0. New field 'schedule' instead.""")

        return pulumi.get(self, "schedule_interval")

    @schedule_interval.setter
    def schedule_interval(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "schedule_interval", value)

    @property
    @pulumi.getter(name="scheduleType")
    def schedule_type(self) -> Optional[pulumi.Input[str]]:
        """
        Default FixedRate. No need to configure this parameter. Deprecated from 1.176.0+. use type in schedule.
        """
        warnings.warn("""Field 'schedule_type' has been deprecated from provider version 1.176.0. New field 'schedule' instead.""", DeprecationWarning)
        pulumi.log.warn("""schedule_type is deprecated: Field 'schedule_type' has been deprecated from provider version 1.176.0. New field 'schedule' instead.""")

        return pulumi.get(self, "schedule_type")

    @schedule_type.setter
    def schedule_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "schedule_type", value)

    @property
    @pulumi.getter(name="sendResolved")
    def send_resolved(self) -> Optional[pulumi.Input[bool]]:
        """
        when new alert is resolved, whether to notify, default is false.
        """
        return pulumi.get(self, "send_resolved")

    @send_resolved.setter
    def send_resolved(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "send_resolved", value)

    @property
    @pulumi.getter(name="severityConfigurations")
    def severity_configurations(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AlertSeverityConfigurationArgs']]]]:
        """
        Severity configuration for new alert.
        """
        return pulumi.get(self, "severity_configurations")

    @severity_configurations.setter
    def severity_configurations(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AlertSeverityConfigurationArgs']]]]):
        pulumi.set(self, "severity_configurations", value)

    @property
    @pulumi.getter(name="templateConfiguration")
    def template_configuration(self) -> Optional[pulumi.Input['AlertTemplateConfigurationArgs']]:
        """
        Template configuration for alert, when `type` is `tpl`.
        """
        return pulumi.get(self, "template_configuration")

    @template_configuration.setter
    def template_configuration(self, value: Optional[pulumi.Input['AlertTemplateConfigurationArgs']]):
        pulumi.set(self, "template_configuration", value)

    @property
    @pulumi.getter
    def threshold(self) -> Optional[pulumi.Input[int]]:
        """
        Evaluation threshold, alert will not fire until the number of triggers is reached. The default is 1.
        """
        return pulumi.get(self, "threshold")

    @threshold.setter
    def threshold(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "threshold", value)

    @property
    @pulumi.getter
    def throttling(self) -> Optional[pulumi.Input[str]]:
        """
        Notification interval, default is no interval. Support number + unit type, for example 60s, 1h, Deprecated from 1.161.0+.
        """
        warnings.warn("""Deprecated from 1.161.0+, use repeat_interval in policy_configuration""", DeprecationWarning)
        pulumi.log.warn("""throttling is deprecated: Deprecated from 1.161.0+, use repeat_interval in policy_configuration""")

        return pulumi.get(self, "throttling")

    @throttling.setter
    def throttling(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "throttling", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[str]]:
        """
        including FixedRate,Hourly,Daily,Weekly,Cron.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter
    def version(self) -> Optional[pulumi.Input[str]]:
        """
        The version of alert, new alert is 2.0.
        """
        return pulumi.get(self, "version")

    @version.setter
    def version(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "version", value)


class Alert(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 alert_description: Optional[pulumi.Input[str]] = None,
                 alert_displayname: Optional[pulumi.Input[str]] = None,
                 alert_name: Optional[pulumi.Input[str]] = None,
                 annotations: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AlertAnnotationArgs']]]]] = None,
                 auto_annotation: Optional[pulumi.Input[bool]] = None,
                 condition: Optional[pulumi.Input[str]] = None,
                 dashboard: Optional[pulumi.Input[str]] = None,
                 group_configuration: Optional[pulumi.Input[pulumi.InputType['AlertGroupConfigurationArgs']]] = None,
                 join_configurations: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AlertJoinConfigurationArgs']]]]] = None,
                 labels: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AlertLabelArgs']]]]] = None,
                 mute_until: Optional[pulumi.Input[int]] = None,
                 no_data_fire: Optional[pulumi.Input[bool]] = None,
                 no_data_severity: Optional[pulumi.Input[int]] = None,
                 notification_lists: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AlertNotificationListArgs']]]]] = None,
                 notify_threshold: Optional[pulumi.Input[int]] = None,
                 policy_configuration: Optional[pulumi.Input[pulumi.InputType['AlertPolicyConfigurationArgs']]] = None,
                 project_name: Optional[pulumi.Input[str]] = None,
                 query_lists: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AlertQueryListArgs']]]]] = None,
                 schedule: Optional[pulumi.Input[pulumi.InputType['AlertScheduleArgs']]] = None,
                 schedule_interval: Optional[pulumi.Input[str]] = None,
                 schedule_type: Optional[pulumi.Input[str]] = None,
                 send_resolved: Optional[pulumi.Input[bool]] = None,
                 severity_configurations: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AlertSeverityConfigurationArgs']]]]] = None,
                 template_configuration: Optional[pulumi.Input[pulumi.InputType['AlertTemplateConfigurationArgs']]] = None,
                 threshold: Optional[pulumi.Input[int]] = None,
                 throttling: Optional[pulumi.Input[str]] = None,
                 type: Optional[pulumi.Input[str]] = None,
                 version: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Log alert is a unit of log service, which is used to monitor and alert the user's logstore status information.
        Log Service enables you to configure alerts based on the charts in a dashboard to monitor the service status in real time.

        For information about SLS Alert and how to use it, see [SLS Alert Overview](https://www.alibabacloud.com/help/en/doc-detail/209202.html)

        > **NOTE:** Available in 1.78.0

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        default = random.RandomInteger("default",
            max=99999,
            min=10000)
        example_project = alicloud.log.Project("exampleProject", description="terraform-example")
        example_store = alicloud.log.Store("exampleStore",
            project=example_project.name,
            retention_period=3650,
            shard_count=3,
            auto_split=True,
            max_split_shard_count=60,
            append_meta=True)
        example_alert = alicloud.log.Alert("exampleAlert",
            project_name=example_project.name,
            alert_name="example-alert",
            alert_displayname="example-alert",
            condition="count> 100",
            dashboard="example-dashboard",
            schedule=alicloud.log.AlertScheduleArgs(
                type="FixedRate",
                interval="5m",
                hour=0,
                day_of_week=0,
                delay=0,
                run_immediately=False,
            ),
            query_lists=[alicloud.log.AlertQueryListArgs(
                logstore=example_store.name,
                chart_title="chart_title",
                start="-60s",
                end="20s",
                query="* AND aliyun",
            )],
            notification_lists=[
                alicloud.log.AlertNotificationListArgs(
                    type="SMS",
                    mobile_lists=[
                        "12345678",
                        "87654321",
                    ],
                    content="alert content",
                ),
                alicloud.log.AlertNotificationListArgs(
                    type="Email",
                    email_lists=[
                        "aliyun@alibaba-inc.com",
                        "tf-example@123.com",
                    ],
                    content="alert content",
                ),
                alicloud.log.AlertNotificationListArgs(
                    type="DingTalk",
                    service_uri="www.aliyun.com",
                    content="alert content",
                ),
            ])
        ```

        Basic Usage for new alert

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        default = random.RandomInteger("default",
            max=99999,
            min=10000)
        example_project = alicloud.log.Project("exampleProject", description="terraform-example")
        example_store = alicloud.log.Store("exampleStore",
            project=example_project.name,
            retention_period=3650,
            shard_count=3,
            auto_split=True,
            max_split_shard_count=60,
            append_meta=True)
        example_2 = alicloud.log.Alert("example-2",
            version="2.0",
            type="default",
            project_name=example_project.name,
            alert_name="example-alert",
            alert_displayname="example-alert",
            mute_until=1632486684,
            no_data_fire=False,
            no_data_severity=8,
            send_resolved=True,
            auto_annotation=True,
            dashboard="example-dashboard",
            schedule=alicloud.log.AlertScheduleArgs(
                type="FixedRate",
                interval="5m",
                hour=0,
                day_of_week=0,
                delay=0,
                run_immediately=False,
            ),
            query_lists=[
                alicloud.log.AlertQueryListArgs(
                    store=example_store.name,
                    store_type="log",
                    project=example_project.name,
                    region="cn-heyuan",
                    chart_title="chart_title",
                    start="-60s",
                    end="20s",
                    query="* AND aliyun | select count(1) as cnt",
                    power_sql_mode="auto",
                ),
                alicloud.log.AlertQueryListArgs(
                    store=example_store.name,
                    store_type="log",
                    project=example_project.name,
                    region="cn-heyuan",
                    chart_title="chart_title",
                    start="-60s",
                    end="20s",
                    query="error | select count(1) as error_cnt",
                    power_sql_mode="enable",
                ),
            ],
            labels=[alicloud.log.AlertLabelArgs(
                key="env",
                value="test",
            )],
            annotations=[
                alicloud.log.AlertAnnotationArgs(
                    key="title",
                    value="alert title",
                ),
                alicloud.log.AlertAnnotationArgs(
                    key="desc",
                    value="alert desc",
                ),
                alicloud.log.AlertAnnotationArgs(
                    key="test_key",
                    value="test value",
                ),
            ],
            group_configuration=alicloud.log.AlertGroupConfigurationArgs(
                type="custom",
                fields=["cnt"],
            ),
            policy_configuration=alicloud.log.AlertPolicyConfigurationArgs(
                alert_policy_id="sls.bultin",
                action_policy_id="sls_test_action",
                repeat_interval="4h",
            ),
            severity_configurations=[
                alicloud.log.AlertSeverityConfigurationArgs(
                    severity=8,
                    eval_condition={
                        "condition": "cnt > 3",
                        "count_condition": "__count__ > 3",
                    },
                ),
                alicloud.log.AlertSeverityConfigurationArgs(
                    severity=6,
                    eval_condition={
                        "condition": "",
                        "count_condition": "__count__ > 0",
                    },
                ),
                alicloud.log.AlertSeverityConfigurationArgs(
                    severity=2,
                    eval_condition={
                        "condition": "",
                        "count_condition": "",
                    },
                ),
            ],
            join_configurations=[alicloud.log.AlertJoinConfigurationArgs(
                type="cross_join",
                condition="",
            )])
        ```

        Basic Usage for alert template

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        default = random.RandomInteger("default",
            max=99999,
            min=10000)
        example_project = alicloud.log.Project("exampleProject", description="terraform-example")
        example_store = alicloud.log.Store("exampleStore",
            project=example_project.name,
            retention_period=3650,
            shard_count=3,
            auto_split=True,
            max_split_shard_count=60,
            append_meta=True)
        example_3 = alicloud.log.Alert("example-3",
            version="2.0",
            type="tpl",
            project_name=example_project.name,
            alert_name="example-alert",
            alert_displayname="example-alert",
            mute_until=1632486684,
            schedule=alicloud.log.AlertScheduleArgs(
                type="FixedRate",
                interval="5m",
                hour=0,
                day_of_week=0,
                delay=0,
                run_immediately=False,
            ),
            template_configuration=alicloud.log.AlertTemplateConfigurationArgs(
                id="sls.app.sls_ack.node.down",
                type="sys",
                lang="cn",
                annotations={},
                tokens={
                    "interval_minute": "5",
                    "default.action_policy": "sls.app.ack.builtin",
                    "default.severity": "6",
                    "sendResolved": "false",
                    "default.project": example_project.name,
                    "default.logstore": "k8s-event",
                    "default.repeatInterval": "4h",
                    "trigger_threshold": "1",
                    "default.clusterId": "example-cluster-id",
                },
            ))
        ```

        ## Import

        Log alert can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:log/alert:Alert example tf-log:tf-log-alert
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] alert_description: Alert description.
        :param pulumi.Input[str] alert_displayname: Alert displayname.
        :param pulumi.Input[str] alert_name: Name of logstore for configuring alarm service.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AlertAnnotationArgs']]]] annotations: Alert template annotations.
        :param pulumi.Input[bool] auto_annotation: whether to add automatic annotation, default is false.
        :param pulumi.Input[str] condition: Join condition.
        :param pulumi.Input[pulumi.InputType['AlertGroupConfigurationArgs']] group_configuration: Group configuration for new alert.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AlertJoinConfigurationArgs']]]] join_configurations: Join configuration for different queries.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AlertLabelArgs']]]] labels: Labels for new alert.
        :param pulumi.Input[int] mute_until: Timestamp, notifications before closing again.
        :param pulumi.Input[bool] no_data_fire: Switch for whether new alert fires when no data happens, default is false.
        :param pulumi.Input[int] no_data_severity: when no data happens, the severity of new alert.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AlertNotificationListArgs']]]] notification_lists: Alarm information notification list, Deprecated from 1.161.0+.
        :param pulumi.Input[int] notify_threshold: Notification threshold, which is not notified until the number of triggers is reached. The default is 1, Deprecated from 1.161.0+.
        :param pulumi.Input[pulumi.InputType['AlertPolicyConfigurationArgs']] policy_configuration: Policy configuration for new alert.
        :param pulumi.Input[str] project_name: The project name.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AlertQueryListArgs']]]] query_lists: Multiple conditions for configured alarm query.
        :param pulumi.Input[pulumi.InputType['AlertScheduleArgs']] schedule: schedule for alert.
        :param pulumi.Input[str] schedule_interval: Execution interval. 60 seconds minimum, such as 60s, 1h. Deprecated from 1.176.0+. use interval in schedule.
        :param pulumi.Input[str] schedule_type: Default FixedRate. No need to configure this parameter. Deprecated from 1.176.0+. use type in schedule.
        :param pulumi.Input[bool] send_resolved: when new alert is resolved, whether to notify, default is false.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AlertSeverityConfigurationArgs']]]] severity_configurations: Severity configuration for new alert.
        :param pulumi.Input[pulumi.InputType['AlertTemplateConfigurationArgs']] template_configuration: Template configuration for alert, when `type` is `tpl`.
        :param pulumi.Input[int] threshold: Evaluation threshold, alert will not fire until the number of triggers is reached. The default is 1.
        :param pulumi.Input[str] throttling: Notification interval, default is no interval. Support number + unit type, for example 60s, 1h, Deprecated from 1.161.0+.
        :param pulumi.Input[str] type: including FixedRate,Hourly,Daily,Weekly,Cron.
        :param pulumi.Input[str] version: The version of alert, new alert is 2.0.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AlertArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Log alert is a unit of log service, which is used to monitor and alert the user's logstore status information.
        Log Service enables you to configure alerts based on the charts in a dashboard to monitor the service status in real time.

        For information about SLS Alert and how to use it, see [SLS Alert Overview](https://www.alibabacloud.com/help/en/doc-detail/209202.html)

        > **NOTE:** Available in 1.78.0

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        default = random.RandomInteger("default",
            max=99999,
            min=10000)
        example_project = alicloud.log.Project("exampleProject", description="terraform-example")
        example_store = alicloud.log.Store("exampleStore",
            project=example_project.name,
            retention_period=3650,
            shard_count=3,
            auto_split=True,
            max_split_shard_count=60,
            append_meta=True)
        example_alert = alicloud.log.Alert("exampleAlert",
            project_name=example_project.name,
            alert_name="example-alert",
            alert_displayname="example-alert",
            condition="count> 100",
            dashboard="example-dashboard",
            schedule=alicloud.log.AlertScheduleArgs(
                type="FixedRate",
                interval="5m",
                hour=0,
                day_of_week=0,
                delay=0,
                run_immediately=False,
            ),
            query_lists=[alicloud.log.AlertQueryListArgs(
                logstore=example_store.name,
                chart_title="chart_title",
                start="-60s",
                end="20s",
                query="* AND aliyun",
            )],
            notification_lists=[
                alicloud.log.AlertNotificationListArgs(
                    type="SMS",
                    mobile_lists=[
                        "12345678",
                        "87654321",
                    ],
                    content="alert content",
                ),
                alicloud.log.AlertNotificationListArgs(
                    type="Email",
                    email_lists=[
                        "aliyun@alibaba-inc.com",
                        "tf-example@123.com",
                    ],
                    content="alert content",
                ),
                alicloud.log.AlertNotificationListArgs(
                    type="DingTalk",
                    service_uri="www.aliyun.com",
                    content="alert content",
                ),
            ])
        ```

        Basic Usage for new alert

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        default = random.RandomInteger("default",
            max=99999,
            min=10000)
        example_project = alicloud.log.Project("exampleProject", description="terraform-example")
        example_store = alicloud.log.Store("exampleStore",
            project=example_project.name,
            retention_period=3650,
            shard_count=3,
            auto_split=True,
            max_split_shard_count=60,
            append_meta=True)
        example_2 = alicloud.log.Alert("example-2",
            version="2.0",
            type="default",
            project_name=example_project.name,
            alert_name="example-alert",
            alert_displayname="example-alert",
            mute_until=1632486684,
            no_data_fire=False,
            no_data_severity=8,
            send_resolved=True,
            auto_annotation=True,
            dashboard="example-dashboard",
            schedule=alicloud.log.AlertScheduleArgs(
                type="FixedRate",
                interval="5m",
                hour=0,
                day_of_week=0,
                delay=0,
                run_immediately=False,
            ),
            query_lists=[
                alicloud.log.AlertQueryListArgs(
                    store=example_store.name,
                    store_type="log",
                    project=example_project.name,
                    region="cn-heyuan",
                    chart_title="chart_title",
                    start="-60s",
                    end="20s",
                    query="* AND aliyun | select count(1) as cnt",
                    power_sql_mode="auto",
                ),
                alicloud.log.AlertQueryListArgs(
                    store=example_store.name,
                    store_type="log",
                    project=example_project.name,
                    region="cn-heyuan",
                    chart_title="chart_title",
                    start="-60s",
                    end="20s",
                    query="error | select count(1) as error_cnt",
                    power_sql_mode="enable",
                ),
            ],
            labels=[alicloud.log.AlertLabelArgs(
                key="env",
                value="test",
            )],
            annotations=[
                alicloud.log.AlertAnnotationArgs(
                    key="title",
                    value="alert title",
                ),
                alicloud.log.AlertAnnotationArgs(
                    key="desc",
                    value="alert desc",
                ),
                alicloud.log.AlertAnnotationArgs(
                    key="test_key",
                    value="test value",
                ),
            ],
            group_configuration=alicloud.log.AlertGroupConfigurationArgs(
                type="custom",
                fields=["cnt"],
            ),
            policy_configuration=alicloud.log.AlertPolicyConfigurationArgs(
                alert_policy_id="sls.bultin",
                action_policy_id="sls_test_action",
                repeat_interval="4h",
            ),
            severity_configurations=[
                alicloud.log.AlertSeverityConfigurationArgs(
                    severity=8,
                    eval_condition={
                        "condition": "cnt > 3",
                        "count_condition": "__count__ > 3",
                    },
                ),
                alicloud.log.AlertSeverityConfigurationArgs(
                    severity=6,
                    eval_condition={
                        "condition": "",
                        "count_condition": "__count__ > 0",
                    },
                ),
                alicloud.log.AlertSeverityConfigurationArgs(
                    severity=2,
                    eval_condition={
                        "condition": "",
                        "count_condition": "",
                    },
                ),
            ],
            join_configurations=[alicloud.log.AlertJoinConfigurationArgs(
                type="cross_join",
                condition="",
            )])
        ```

        Basic Usage for alert template

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        default = random.RandomInteger("default",
            max=99999,
            min=10000)
        example_project = alicloud.log.Project("exampleProject", description="terraform-example")
        example_store = alicloud.log.Store("exampleStore",
            project=example_project.name,
            retention_period=3650,
            shard_count=3,
            auto_split=True,
            max_split_shard_count=60,
            append_meta=True)
        example_3 = alicloud.log.Alert("example-3",
            version="2.0",
            type="tpl",
            project_name=example_project.name,
            alert_name="example-alert",
            alert_displayname="example-alert",
            mute_until=1632486684,
            schedule=alicloud.log.AlertScheduleArgs(
                type="FixedRate",
                interval="5m",
                hour=0,
                day_of_week=0,
                delay=0,
                run_immediately=False,
            ),
            template_configuration=alicloud.log.AlertTemplateConfigurationArgs(
                id="sls.app.sls_ack.node.down",
                type="sys",
                lang="cn",
                annotations={},
                tokens={
                    "interval_minute": "5",
                    "default.action_policy": "sls.app.ack.builtin",
                    "default.severity": "6",
                    "sendResolved": "false",
                    "default.project": example_project.name,
                    "default.logstore": "k8s-event",
                    "default.repeatInterval": "4h",
                    "trigger_threshold": "1",
                    "default.clusterId": "example-cluster-id",
                },
            ))
        ```

        ## Import

        Log alert can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:log/alert:Alert example tf-log:tf-log-alert
        ```

        :param str resource_name: The name of the resource.
        :param AlertArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AlertArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 alert_description: Optional[pulumi.Input[str]] = None,
                 alert_displayname: Optional[pulumi.Input[str]] = None,
                 alert_name: Optional[pulumi.Input[str]] = None,
                 annotations: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AlertAnnotationArgs']]]]] = None,
                 auto_annotation: Optional[pulumi.Input[bool]] = None,
                 condition: Optional[pulumi.Input[str]] = None,
                 dashboard: Optional[pulumi.Input[str]] = None,
                 group_configuration: Optional[pulumi.Input[pulumi.InputType['AlertGroupConfigurationArgs']]] = None,
                 join_configurations: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AlertJoinConfigurationArgs']]]]] = None,
                 labels: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AlertLabelArgs']]]]] = None,
                 mute_until: Optional[pulumi.Input[int]] = None,
                 no_data_fire: Optional[pulumi.Input[bool]] = None,
                 no_data_severity: Optional[pulumi.Input[int]] = None,
                 notification_lists: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AlertNotificationListArgs']]]]] = None,
                 notify_threshold: Optional[pulumi.Input[int]] = None,
                 policy_configuration: Optional[pulumi.Input[pulumi.InputType['AlertPolicyConfigurationArgs']]] = None,
                 project_name: Optional[pulumi.Input[str]] = None,
                 query_lists: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AlertQueryListArgs']]]]] = None,
                 schedule: Optional[pulumi.Input[pulumi.InputType['AlertScheduleArgs']]] = None,
                 schedule_interval: Optional[pulumi.Input[str]] = None,
                 schedule_type: Optional[pulumi.Input[str]] = None,
                 send_resolved: Optional[pulumi.Input[bool]] = None,
                 severity_configurations: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AlertSeverityConfigurationArgs']]]]] = None,
                 template_configuration: Optional[pulumi.Input[pulumi.InputType['AlertTemplateConfigurationArgs']]] = None,
                 threshold: Optional[pulumi.Input[int]] = None,
                 throttling: Optional[pulumi.Input[str]] = None,
                 type: Optional[pulumi.Input[str]] = None,
                 version: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AlertArgs.__new__(AlertArgs)

            __props__.__dict__["alert_description"] = alert_description
            if alert_displayname is None and not opts.urn:
                raise TypeError("Missing required property 'alert_displayname'")
            __props__.__dict__["alert_displayname"] = alert_displayname
            if alert_name is None and not opts.urn:
                raise TypeError("Missing required property 'alert_name'")
            __props__.__dict__["alert_name"] = alert_name
            __props__.__dict__["annotations"] = annotations
            __props__.__dict__["auto_annotation"] = auto_annotation
            if condition is not None and not opts.urn:
                warnings.warn("""Deprecated from 1.161.0+, use eval_condition in severity_configurations""", DeprecationWarning)
                pulumi.log.warn("""condition is deprecated: Deprecated from 1.161.0+, use eval_condition in severity_configurations""")
            __props__.__dict__["condition"] = condition
            if dashboard is not None and not opts.urn:
                warnings.warn("""Deprecated from 1.161.0+, use dashboardId in query_list""", DeprecationWarning)
                pulumi.log.warn("""dashboard is deprecated: Deprecated from 1.161.0+, use dashboardId in query_list""")
            __props__.__dict__["dashboard"] = dashboard
            __props__.__dict__["group_configuration"] = group_configuration
            __props__.__dict__["join_configurations"] = join_configurations
            __props__.__dict__["labels"] = labels
            __props__.__dict__["mute_until"] = mute_until
            __props__.__dict__["no_data_fire"] = no_data_fire
            __props__.__dict__["no_data_severity"] = no_data_severity
            if notification_lists is not None and not opts.urn:
                warnings.warn("""Deprecated from 1.161.0+, use policy_configuration for notification""", DeprecationWarning)
                pulumi.log.warn("""notification_lists is deprecated: Deprecated from 1.161.0+, use policy_configuration for notification""")
            __props__.__dict__["notification_lists"] = notification_lists
            if notify_threshold is not None and not opts.urn:
                warnings.warn("""Deprecated from 1.161.0+, use threshold""", DeprecationWarning)
                pulumi.log.warn("""notify_threshold is deprecated: Deprecated from 1.161.0+, use threshold""")
            __props__.__dict__["notify_threshold"] = notify_threshold
            __props__.__dict__["policy_configuration"] = policy_configuration
            if project_name is None and not opts.urn:
                raise TypeError("Missing required property 'project_name'")
            __props__.__dict__["project_name"] = project_name
            __props__.__dict__["query_lists"] = query_lists
            __props__.__dict__["schedule"] = schedule
            if schedule_interval is not None and not opts.urn:
                warnings.warn("""Field 'schedule_interval' has been deprecated from provider version 1.176.0. New field 'schedule' instead.""", DeprecationWarning)
                pulumi.log.warn("""schedule_interval is deprecated: Field 'schedule_interval' has been deprecated from provider version 1.176.0. New field 'schedule' instead.""")
            __props__.__dict__["schedule_interval"] = schedule_interval
            if schedule_type is not None and not opts.urn:
                warnings.warn("""Field 'schedule_type' has been deprecated from provider version 1.176.0. New field 'schedule' instead.""", DeprecationWarning)
                pulumi.log.warn("""schedule_type is deprecated: Field 'schedule_type' has been deprecated from provider version 1.176.0. New field 'schedule' instead.""")
            __props__.__dict__["schedule_type"] = schedule_type
            __props__.__dict__["send_resolved"] = send_resolved
            __props__.__dict__["severity_configurations"] = severity_configurations
            __props__.__dict__["template_configuration"] = template_configuration
            __props__.__dict__["threshold"] = threshold
            if throttling is not None and not opts.urn:
                warnings.warn("""Deprecated from 1.161.0+, use repeat_interval in policy_configuration""", DeprecationWarning)
                pulumi.log.warn("""throttling is deprecated: Deprecated from 1.161.0+, use repeat_interval in policy_configuration""")
            __props__.__dict__["throttling"] = throttling
            __props__.__dict__["type"] = type
            __props__.__dict__["version"] = version
        super(Alert, __self__).__init__(
            'alicloud:log/alert:Alert',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            alert_description: Optional[pulumi.Input[str]] = None,
            alert_displayname: Optional[pulumi.Input[str]] = None,
            alert_name: Optional[pulumi.Input[str]] = None,
            annotations: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AlertAnnotationArgs']]]]] = None,
            auto_annotation: Optional[pulumi.Input[bool]] = None,
            condition: Optional[pulumi.Input[str]] = None,
            dashboard: Optional[pulumi.Input[str]] = None,
            group_configuration: Optional[pulumi.Input[pulumi.InputType['AlertGroupConfigurationArgs']]] = None,
            join_configurations: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AlertJoinConfigurationArgs']]]]] = None,
            labels: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AlertLabelArgs']]]]] = None,
            mute_until: Optional[pulumi.Input[int]] = None,
            no_data_fire: Optional[pulumi.Input[bool]] = None,
            no_data_severity: Optional[pulumi.Input[int]] = None,
            notification_lists: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AlertNotificationListArgs']]]]] = None,
            notify_threshold: Optional[pulumi.Input[int]] = None,
            policy_configuration: Optional[pulumi.Input[pulumi.InputType['AlertPolicyConfigurationArgs']]] = None,
            project_name: Optional[pulumi.Input[str]] = None,
            query_lists: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AlertQueryListArgs']]]]] = None,
            schedule: Optional[pulumi.Input[pulumi.InputType['AlertScheduleArgs']]] = None,
            schedule_interval: Optional[pulumi.Input[str]] = None,
            schedule_type: Optional[pulumi.Input[str]] = None,
            send_resolved: Optional[pulumi.Input[bool]] = None,
            severity_configurations: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AlertSeverityConfigurationArgs']]]]] = None,
            template_configuration: Optional[pulumi.Input[pulumi.InputType['AlertTemplateConfigurationArgs']]] = None,
            threshold: Optional[pulumi.Input[int]] = None,
            throttling: Optional[pulumi.Input[str]] = None,
            type: Optional[pulumi.Input[str]] = None,
            version: Optional[pulumi.Input[str]] = None) -> 'Alert':
        """
        Get an existing Alert resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] alert_description: Alert description.
        :param pulumi.Input[str] alert_displayname: Alert displayname.
        :param pulumi.Input[str] alert_name: Name of logstore for configuring alarm service.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AlertAnnotationArgs']]]] annotations: Alert template annotations.
        :param pulumi.Input[bool] auto_annotation: whether to add automatic annotation, default is false.
        :param pulumi.Input[str] condition: Join condition.
        :param pulumi.Input[pulumi.InputType['AlertGroupConfigurationArgs']] group_configuration: Group configuration for new alert.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AlertJoinConfigurationArgs']]]] join_configurations: Join configuration for different queries.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AlertLabelArgs']]]] labels: Labels for new alert.
        :param pulumi.Input[int] mute_until: Timestamp, notifications before closing again.
        :param pulumi.Input[bool] no_data_fire: Switch for whether new alert fires when no data happens, default is false.
        :param pulumi.Input[int] no_data_severity: when no data happens, the severity of new alert.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AlertNotificationListArgs']]]] notification_lists: Alarm information notification list, Deprecated from 1.161.0+.
        :param pulumi.Input[int] notify_threshold: Notification threshold, which is not notified until the number of triggers is reached. The default is 1, Deprecated from 1.161.0+.
        :param pulumi.Input[pulumi.InputType['AlertPolicyConfigurationArgs']] policy_configuration: Policy configuration for new alert.
        :param pulumi.Input[str] project_name: The project name.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AlertQueryListArgs']]]] query_lists: Multiple conditions for configured alarm query.
        :param pulumi.Input[pulumi.InputType['AlertScheduleArgs']] schedule: schedule for alert.
        :param pulumi.Input[str] schedule_interval: Execution interval. 60 seconds minimum, such as 60s, 1h. Deprecated from 1.176.0+. use interval in schedule.
        :param pulumi.Input[str] schedule_type: Default FixedRate. No need to configure this parameter. Deprecated from 1.176.0+. use type in schedule.
        :param pulumi.Input[bool] send_resolved: when new alert is resolved, whether to notify, default is false.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AlertSeverityConfigurationArgs']]]] severity_configurations: Severity configuration for new alert.
        :param pulumi.Input[pulumi.InputType['AlertTemplateConfigurationArgs']] template_configuration: Template configuration for alert, when `type` is `tpl`.
        :param pulumi.Input[int] threshold: Evaluation threshold, alert will not fire until the number of triggers is reached. The default is 1.
        :param pulumi.Input[str] throttling: Notification interval, default is no interval. Support number + unit type, for example 60s, 1h, Deprecated from 1.161.0+.
        :param pulumi.Input[str] type: including FixedRate,Hourly,Daily,Weekly,Cron.
        :param pulumi.Input[str] version: The version of alert, new alert is 2.0.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AlertState.__new__(_AlertState)

        __props__.__dict__["alert_description"] = alert_description
        __props__.__dict__["alert_displayname"] = alert_displayname
        __props__.__dict__["alert_name"] = alert_name
        __props__.__dict__["annotations"] = annotations
        __props__.__dict__["auto_annotation"] = auto_annotation
        __props__.__dict__["condition"] = condition
        __props__.__dict__["dashboard"] = dashboard
        __props__.__dict__["group_configuration"] = group_configuration
        __props__.__dict__["join_configurations"] = join_configurations
        __props__.__dict__["labels"] = labels
        __props__.__dict__["mute_until"] = mute_until
        __props__.__dict__["no_data_fire"] = no_data_fire
        __props__.__dict__["no_data_severity"] = no_data_severity
        __props__.__dict__["notification_lists"] = notification_lists
        __props__.__dict__["notify_threshold"] = notify_threshold
        __props__.__dict__["policy_configuration"] = policy_configuration
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["query_lists"] = query_lists
        __props__.__dict__["schedule"] = schedule
        __props__.__dict__["schedule_interval"] = schedule_interval
        __props__.__dict__["schedule_type"] = schedule_type
        __props__.__dict__["send_resolved"] = send_resolved
        __props__.__dict__["severity_configurations"] = severity_configurations
        __props__.__dict__["template_configuration"] = template_configuration
        __props__.__dict__["threshold"] = threshold
        __props__.__dict__["throttling"] = throttling
        __props__.__dict__["type"] = type
        __props__.__dict__["version"] = version
        return Alert(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="alertDescription")
    def alert_description(self) -> pulumi.Output[Optional[str]]:
        """
        Alert description.
        """
        return pulumi.get(self, "alert_description")

    @property
    @pulumi.getter(name="alertDisplayname")
    def alert_displayname(self) -> pulumi.Output[str]:
        """
        Alert displayname.
        """
        return pulumi.get(self, "alert_displayname")

    @property
    @pulumi.getter(name="alertName")
    def alert_name(self) -> pulumi.Output[str]:
        """
        Name of logstore for configuring alarm service.
        """
        return pulumi.get(self, "alert_name")

    @property
    @pulumi.getter
    def annotations(self) -> pulumi.Output[Optional[Sequence['outputs.AlertAnnotation']]]:
        """
        Alert template annotations.
        """
        return pulumi.get(self, "annotations")

    @property
    @pulumi.getter(name="autoAnnotation")
    def auto_annotation(self) -> pulumi.Output[Optional[bool]]:
        """
        whether to add automatic annotation, default is false.
        """
        return pulumi.get(self, "auto_annotation")

    @property
    @pulumi.getter
    def condition(self) -> pulumi.Output[Optional[str]]:
        """
        Join condition.
        """
        warnings.warn("""Deprecated from 1.161.0+, use eval_condition in severity_configurations""", DeprecationWarning)
        pulumi.log.warn("""condition is deprecated: Deprecated from 1.161.0+, use eval_condition in severity_configurations""")

        return pulumi.get(self, "condition")

    @property
    @pulumi.getter
    def dashboard(self) -> pulumi.Output[Optional[str]]:
        warnings.warn("""Deprecated from 1.161.0+, use dashboardId in query_list""", DeprecationWarning)
        pulumi.log.warn("""dashboard is deprecated: Deprecated from 1.161.0+, use dashboardId in query_list""")

        return pulumi.get(self, "dashboard")

    @property
    @pulumi.getter(name="groupConfiguration")
    def group_configuration(self) -> pulumi.Output[Optional['outputs.AlertGroupConfiguration']]:
        """
        Group configuration for new alert.
        """
        return pulumi.get(self, "group_configuration")

    @property
    @pulumi.getter(name="joinConfigurations")
    def join_configurations(self) -> pulumi.Output[Optional[Sequence['outputs.AlertJoinConfiguration']]]:
        """
        Join configuration for different queries.
        """
        return pulumi.get(self, "join_configurations")

    @property
    @pulumi.getter
    def labels(self) -> pulumi.Output[Optional[Sequence['outputs.AlertLabel']]]:
        """
        Labels for new alert.
        """
        return pulumi.get(self, "labels")

    @property
    @pulumi.getter(name="muteUntil")
    def mute_until(self) -> pulumi.Output[int]:
        """
        Timestamp, notifications before closing again.
        """
        return pulumi.get(self, "mute_until")

    @property
    @pulumi.getter(name="noDataFire")
    def no_data_fire(self) -> pulumi.Output[Optional[bool]]:
        """
        Switch for whether new alert fires when no data happens, default is false.
        """
        return pulumi.get(self, "no_data_fire")

    @property
    @pulumi.getter(name="noDataSeverity")
    def no_data_severity(self) -> pulumi.Output[Optional[int]]:
        """
        when no data happens, the severity of new alert.
        """
        return pulumi.get(self, "no_data_severity")

    @property
    @pulumi.getter(name="notificationLists")
    def notification_lists(self) -> pulumi.Output[Optional[Sequence['outputs.AlertNotificationList']]]:
        """
        Alarm information notification list, Deprecated from 1.161.0+.
        """
        warnings.warn("""Deprecated from 1.161.0+, use policy_configuration for notification""", DeprecationWarning)
        pulumi.log.warn("""notification_lists is deprecated: Deprecated from 1.161.0+, use policy_configuration for notification""")

        return pulumi.get(self, "notification_lists")

    @property
    @pulumi.getter(name="notifyThreshold")
    def notify_threshold(self) -> pulumi.Output[Optional[int]]:
        """
        Notification threshold, which is not notified until the number of triggers is reached. The default is 1, Deprecated from 1.161.0+.
        """
        warnings.warn("""Deprecated from 1.161.0+, use threshold""", DeprecationWarning)
        pulumi.log.warn("""notify_threshold is deprecated: Deprecated from 1.161.0+, use threshold""")

        return pulumi.get(self, "notify_threshold")

    @property
    @pulumi.getter(name="policyConfiguration")
    def policy_configuration(self) -> pulumi.Output[Optional['outputs.AlertPolicyConfiguration']]:
        """
        Policy configuration for new alert.
        """
        return pulumi.get(self, "policy_configuration")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[str]:
        """
        The project name.
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="queryLists")
    def query_lists(self) -> pulumi.Output[Optional[Sequence['outputs.AlertQueryList']]]:
        """
        Multiple conditions for configured alarm query.
        """
        return pulumi.get(self, "query_lists")

    @property
    @pulumi.getter
    def schedule(self) -> pulumi.Output[Optional['outputs.AlertSchedule']]:
        """
        schedule for alert.
        """
        return pulumi.get(self, "schedule")

    @property
    @pulumi.getter(name="scheduleInterval")
    def schedule_interval(self) -> pulumi.Output[str]:
        """
        Execution interval. 60 seconds minimum, such as 60s, 1h. Deprecated from 1.176.0+. use interval in schedule.
        """
        warnings.warn("""Field 'schedule_interval' has been deprecated from provider version 1.176.0. New field 'schedule' instead.""", DeprecationWarning)
        pulumi.log.warn("""schedule_interval is deprecated: Field 'schedule_interval' has been deprecated from provider version 1.176.0. New field 'schedule' instead.""")

        return pulumi.get(self, "schedule_interval")

    @property
    @pulumi.getter(name="scheduleType")
    def schedule_type(self) -> pulumi.Output[str]:
        """
        Default FixedRate. No need to configure this parameter. Deprecated from 1.176.0+. use type in schedule.
        """
        warnings.warn("""Field 'schedule_type' has been deprecated from provider version 1.176.0. New field 'schedule' instead.""", DeprecationWarning)
        pulumi.log.warn("""schedule_type is deprecated: Field 'schedule_type' has been deprecated from provider version 1.176.0. New field 'schedule' instead.""")

        return pulumi.get(self, "schedule_type")

    @property
    @pulumi.getter(name="sendResolved")
    def send_resolved(self) -> pulumi.Output[Optional[bool]]:
        """
        when new alert is resolved, whether to notify, default is false.
        """
        return pulumi.get(self, "send_resolved")

    @property
    @pulumi.getter(name="severityConfigurations")
    def severity_configurations(self) -> pulumi.Output[Optional[Sequence['outputs.AlertSeverityConfiguration']]]:
        """
        Severity configuration for new alert.
        """
        return pulumi.get(self, "severity_configurations")

    @property
    @pulumi.getter(name="templateConfiguration")
    def template_configuration(self) -> pulumi.Output[Optional['outputs.AlertTemplateConfiguration']]:
        """
        Template configuration for alert, when `type` is `tpl`.
        """
        return pulumi.get(self, "template_configuration")

    @property
    @pulumi.getter
    def threshold(self) -> pulumi.Output[int]:
        """
        Evaluation threshold, alert will not fire until the number of triggers is reached. The default is 1.
        """
        return pulumi.get(self, "threshold")

    @property
    @pulumi.getter
    def throttling(self) -> pulumi.Output[Optional[str]]:
        """
        Notification interval, default is no interval. Support number + unit type, for example 60s, 1h, Deprecated from 1.161.0+.
        """
        warnings.warn("""Deprecated from 1.161.0+, use repeat_interval in policy_configuration""", DeprecationWarning)
        pulumi.log.warn("""throttling is deprecated: Deprecated from 1.161.0+, use repeat_interval in policy_configuration""")

        return pulumi.get(self, "throttling")

    @property
    @pulumi.getter
    def type(self) -> pulumi.Output[Optional[str]]:
        """
        including FixedRate,Hourly,Daily,Weekly,Cron.
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def version(self) -> pulumi.Output[Optional[str]]:
        """
        The version of alert, new alert is 2.0.
        """
        return pulumi.get(self, "version")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetAccountAliasesResult',
    'AwaitableGetAccountAliasesResult',
    'get_account_aliases',
    'get_account_aliases_output',
]

@pulumi.output_type
class GetAccountAliasesResult:
    """
    A collection of values returned by getAccountAliases.
    """
    def __init__(__self__, account_alias=None, id=None, output_file=None):
        if account_alias and not isinstance(account_alias, str):
            raise TypeError("Expected argument 'account_alias' to be a str")
        pulumi.set(__self__, "account_alias", account_alias)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)

    @property
    @pulumi.getter(name="accountAlias")
    def account_alias(self) -> str:
        return pulumi.get(self, "account_alias")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")


class AwaitableGetAccountAliasesResult(GetAccountAliasesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAccountAliasesResult(
            account_alias=self.account_alias,
            id=self.id,
            output_file=self.output_file)


def get_account_aliases(output_file: Optional[str] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAccountAliasesResult:
    """
    Use this data source to access information about an existing resource.
    """
    __args__ = dict()
    __args__['outputFile'] = output_file
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:ram/getAccountAliases:getAccountAliases', __args__, opts=opts, typ=GetAccountAliasesResult).value

    return AwaitableGetAccountAliasesResult(
        account_alias=pulumi.get(__ret__, 'account_alias'),
        id=pulumi.get(__ret__, 'id'),
        output_file=pulumi.get(__ret__, 'output_file'))


@_utilities.lift_output_func(get_account_aliases)
def get_account_aliases_output(output_file: Optional[pulumi.Input[Optional[str]]] = None,
                               opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetAccountAliasesResult]:
    """
    Use this data source to access information about an existing resource.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetPolicyVersionsResult',
    'AwaitableGetPolicyVersionsResult',
    'get_policy_versions',
    'get_policy_versions_output',
]

@pulumi.output_type
class GetPolicyVersionsResult:
    """
    A collection of values returned by getPolicyVersions.
    """
    def __init__(__self__, enable_details=None, id=None, ids=None, output_file=None, policy_name=None, policy_type=None, versions=None):
        if enable_details and not isinstance(enable_details, bool):
            raise TypeError("Expected argument 'enable_details' to be a bool")
        pulumi.set(__self__, "enable_details", enable_details)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if policy_name and not isinstance(policy_name, str):
            raise TypeError("Expected argument 'policy_name' to be a str")
        pulumi.set(__self__, "policy_name", policy_name)
        if policy_type and not isinstance(policy_type, str):
            raise TypeError("Expected argument 'policy_type' to be a str")
        pulumi.set(__self__, "policy_type", policy_type)
        if versions and not isinstance(versions, list):
            raise TypeError("Expected argument 'versions' to be a list")
        pulumi.set(__self__, "versions", versions)

    @property
    @pulumi.getter(name="enableDetails")
    def enable_details(self) -> Optional[bool]:
        return pulumi.get(self, "enable_details")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        """
        A list of policy version IDs.
        """
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter(name="policyName")
    def policy_name(self) -> str:
        return pulumi.get(self, "policy_name")

    @property
    @pulumi.getter(name="policyType")
    def policy_type(self) -> str:
        return pulumi.get(self, "policy_type")

    @property
    @pulumi.getter
    def versions(self) -> Sequence['outputs.GetPolicyVersionsVersionResult']:
        """
        A list of policy versions. Each element contains the following attributes:
        """
        return pulumi.get(self, "versions")


class AwaitableGetPolicyVersionsResult(GetPolicyVersionsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetPolicyVersionsResult(
            enable_details=self.enable_details,
            id=self.id,
            ids=self.ids,
            output_file=self.output_file,
            policy_name=self.policy_name,
            policy_type=self.policy_type,
            versions=self.versions)


def get_policy_versions(enable_details: Optional[bool] = None,
                        ids: Optional[Sequence[str]] = None,
                        output_file: Optional[str] = None,
                        policy_name: Optional[str] = None,
                        policy_type: Optional[str] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetPolicyVersionsResult:
    """
    This data source provides the Resource Manager Policy Versions of the current Alibaba Cloud user.

    > **NOTE:**  Available in 1.85.0+.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    default = alicloud.resourcemanager.get_policy_versions(policy_name="tftest",
        policy_type="Custom")
    pulumi.export("firstPolicyVersionId", default.versions[0].id)
    ```


    :param bool enable_details: Default to `false`. Set it to true can output more details.
    :param Sequence[str] ids: A list of policy version IDs.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str policy_name: The name of the policy.
    :param str policy_type: The type of the policy. Valid values:`Custom` and `System`.
    """
    __args__ = dict()
    __args__['enableDetails'] = enable_details
    __args__['ids'] = ids
    __args__['outputFile'] = output_file
    __args__['policyName'] = policy_name
    __args__['policyType'] = policy_type
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:resourcemanager/getPolicyVersions:getPolicyVersions', __args__, opts=opts, typ=GetPolicyVersionsResult).value

    return AwaitableGetPolicyVersionsResult(
        enable_details=pulumi.get(__ret__, 'enable_details'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        output_file=pulumi.get(__ret__, 'output_file'),
        policy_name=pulumi.get(__ret__, 'policy_name'),
        policy_type=pulumi.get(__ret__, 'policy_type'),
        versions=pulumi.get(__ret__, 'versions'))


@_utilities.lift_output_func(get_policy_versions)
def get_policy_versions_output(enable_details: Optional[pulumi.Input[Optional[bool]]] = None,
                               ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                               output_file: Optional[pulumi.Input[Optional[str]]] = None,
                               policy_name: Optional[pulumi.Input[str]] = None,
                               policy_type: Optional[pulumi.Input[str]] = None,
                               opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetPolicyVersionsResult]:
    """
    This data source provides the Resource Manager Policy Versions of the current Alibaba Cloud user.

    > **NOTE:**  Available in 1.85.0+.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    default = alicloud.resourcemanager.get_policy_versions(policy_name="tftest",
        policy_type="Custom")
    pulumi.export("firstPolicyVersionId", default.versions[0].id)
    ```


    :param bool enable_details: Default to `false`. Set it to true can output more details.
    :param Sequence[str] ids: A list of policy version IDs.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str policy_name: The name of the policy.
    :param str policy_type: The type of the policy. Valid values:`Custom` and `System`.
    """
    ...
